function [ECOTRAN, ECOTRAN_PEDIGREE] = f_TerminalDetritus_08032018(original_ECOTRAN, original_ECOTRAN_PEDIGREE)
% take ECOTRAN and rebuild terminal detritus pools by adding an ULTIMATE detritus pool; 
% this function is necessary for management of bacterial metabolism of terminal benthic detritus in time-dynamic simulations
% revision date: 8-3-2018


% *************************************************************************
% STEP 1: unpack ECOTRAN structure variables-------------------------------
new_EnergyBudget_matrix                             = original_ECOTRAN.EnergyBudget_matrix;
new_AggLabel                                        = original_ECOTRAN.AggLabel;

new_EcotrophicEfficiency_predation                  = original_ECOTRAN.EcotrophicEfficiency_predation;
new_EcotrophicEfficiency_BA                         = original_ECOTRAN.EcotrophicEfficiency_BA;
new_EcotrophicEfficiency_EM                         = original_ECOTRAN.EcotrophicEfficiency_EM;
new_EcotrophicEfficiency                            = original_ECOTRAN.EcotrophicEfficiency;

new_BioenergeticBudget                              = original_ECOTRAN.BioenergeticBudget; 
new_BioenergeticBudget_ProductionDetail             = original_ECOTRAN.BioenergeticBudget_ProductionDetail;
new_BioenergeticBudget_OtherMortDetail              = original_ECOTRAN.BioenergeticBudget_OtherMortDetail;
new_BioenergeticBudget_FecesDetail                  = original_ECOTRAN.BioenergeticBudget_FecesDetail;
new_ProductionBudget                                = original_ECOTRAN.ProductionBudget;
new_ProductionBudget_OtherMortDetail                = original_ECOTRAN.ProductionBudget_OtherMortDetail;

new_GroupType                                       = original_ECOTRAN.GroupType;
new_TransferEfficiency                              = original_ECOTRAN.TransferEfficiency;

new_ProductionLossScaler                            = original_ECOTRAN.ProductionLossScaler;
new_RetentionScaler                                 = original_ECOTRAN.RetentionScaler;
new_FunctionalResponseParams                        = original_ECOTRAN.FunctionalResponseParams;

new_EwE_Biomass                                     = original_ECOTRAN.EwE_Biomass;
new_EwE_PB                                          = original_ECOTRAN.EwE_PB;
new_EwE_QB                                          = original_ECOTRAN.EwE_QB;
new_EwE_PQ                                          = original_ECOTRAN.EwE_PQ;
new_EwE_AE                                          = original_ECOTRAN.EwE_AE;
new_EwE_BA                                          = original_ECOTRAN.EwE_BA;
new_EwE_EM                                          = original_ECOTRAN.EwE_EM;

new_DetritusFate_feces                              = original_ECOTRAN.DetritusFate_feces;
new_DetritusFate_senescence                         = original_ECOTRAN.DetritusFate_senescence;
new_ExcretionFate                                   = original_ECOTRAN.ExcretionFate;
new_EggFate                                         = original_ECOTRAN.EggFate;

new_EwE_Landings                                    = original_ECOTRAN.EwE_Landings;
new_EwE_Discards                                    = original_ECOTRAN.EwE_Discards;
new_EwE_TotalFishery                                = original_ECOTRAN.EwE_TotalFishery;

[num_E2Egroups, E2E_clms, num_MonteCarlo]           = size(new_EnergyBudget_matrix);

looky_BA                                            = find(new_GroupType        == original_ECOTRAN.GroupTypeDef_BA);
looky_EM                                            = find(new_GroupType        == original_ECOTRAN.GroupTypeDef_EM);
looky_terminalPlgcDetr                              = find(new_GroupType        == original_ECOTRAN.GroupTypeDef_terminalPlgcDetr);
looky_terminalBnthDetr                              = find(new_GroupType        == original_ECOTRAN.GroupTypeDef_terminalBnthDetr);
looky_NO3                                           = find(new_GroupType        == original_ECOTRAN.GroupTypeDef_NO3);
looky_plgcNH4                                       = find(new_GroupType        == original_ECOTRAN.GroupTypeDef_plgcNH4);
looky_bnthNH4                                       = find(new_GroupType        == original_ECOTRAN.GroupTypeDef_bnthNH4);
looky_AllNutrients                                  = [looky_NO3; looky_plgcNH4; looky_bnthNH4];
looky_eggs                                          = find(new_GroupType == original_ECOTRAN.GroupTypeDef_eggs);
looky_fishery                                       = find(floor(new_GroupType) == original_ECOTRAN.GroupTypeDef_fishery);
num_nutrients                                       = length(looky_AllNutrients);



% step 1b: ECOTRAN_PEDIGREE -----------------------------------------------
% defined pedigrees for all model groups
new_CV_EnergyBudget_matrix                          = original_ECOTRAN_PEDIGREE.CV_EnergyBudget_matrix;
new_CV_ConsumptionBudget                            = original_ECOTRAN_PEDIGREE.CV_ConsumptionBudget;
new_PEDIGREE_other                                  = original_ECOTRAN_PEDIGREE.PEDIGREE_other;         % "other" defined input pedigree terms for the whole model in general
%                                                                                                           row 1 = PEDIGREE_eggs
%                                                                                                           row 2 = PEDIGREE_predation
%                                                                                                           row 3 = PEDIGREE_senescence
%                                                                                                           row 4 = PEDIGREE_BacterialMTBLSM
%                                                                                                           row 5 = PEDIGREE_NutrientUptake
PEDIGREE_BacterialMTBLSM                            = new_PEDIGREE_other(4);                        	% defined pedigree for implicit bacterial metabolism of terminal detritus (CV)





% *************************************************************************
% STEP 2: add labile benthic detritus pools--------------------------------
% QQQ change name from labile
% % % % num_LabileDetritus                            = 1; % number of labile detritus pools for bacterial recycling
num_ULTIMATEdetritus                                        = 1; % number of ultimate detritus pools for bacterial recycling
% % % new_num_E2Egroups                               = num_E2Egroups + num_LabileDetritus;
new_num_E2Egroups                                           = num_E2Egroups + num_ULTIMATEdetritus;
% % % new_E2E_clms                                    = E2E_clms + num_LabileDetritus;
new_E2E_clms                                                = E2E_clms + num_ULTIMATEdetritus;
% % % looky_labileBnthDetr                            = new_num_E2Egroups;
looky_ULTIMATEdetritus                                      = new_num_E2Egroups;


% update AggLabel ---------------------------------------------------------
AggLabel_BA                                                 = new_AggLabel{looky_BA};
AggLabel_EM                                                 = new_AggLabel{looky_EM};
% % % new_AggLabel{looky_labileBnthDetr}                                      = 'TERMINAL detritus';      % (changed label, JRuz 8-2-2018)
new_AggLabel{looky_ULTIMATEdetritus}                        = 'ULTIMATE detritus';
% % % new_AggLabel{looky_BA + num_LabileDetritus}                             = AggLabel_BA;
% % % new_AggLabel{looky_EM + num_LabileDetritus}                             = AggLabel_EM;
new_AggLabel{looky_BA + num_ULTIMATEdetritus}               = AggLabel_BA;
new_AggLabel{looky_EM + num_ULTIMATEdetritus}               = AggLabel_EM;


% update EcotrophicEfficiency terms ---------------------------------------
% % % new_EcotrophicEfficiency_predation(looky_labileBnthDetr)        = 1; % assume 100% of labile detritus goes to NH4, change this via TE
% % % new_EcotrophicEfficiency(looky_labileBnthDetr)                  = 1; % assume 100% of labile detritus goes to NH4, change this via TE
% % % new_EcotrophicEfficiency_BA(looky_labileBnthDetr)               = 0;
% % % new_EcotrophicEfficiency_EM(looky_labileBnthDetr)               = 0;
new_EcotrophicEfficiency_predation(looky_ULTIMATEdetritus)	= 1; % assume 100% of ULTIMATE detritus goes to NH4, change this via TE
new_EcotrophicEfficiency(looky_ULTIMATEdetritus)           	= 1; % assume 100% of ULTIMATE detritus goes to NH4, change this via TE
new_EcotrophicEfficiency_BA(looky_ULTIMATEdetritus)       	= 0;
new_EcotrophicEfficiency_EM(looky_ULTIMATEdetritus)        	= 0;


% BioenergeticBudget ------------------------------------------------------
%   ECOTRAN.BioenergeticBudget (sum of each clm = 1, except for fisheries)
%           row 1 = BioenergeticBudget_production
%           row 2 = BioenergeticBudget_feces
%           row 3 = BioenergeticBudget_metabolism
% % % new_BioenergeticBudget(1:3, looky_labileBnthDetr)                   = 0;
% % % new_BioenergeticBudget(3, looky_labileBnthDetr)                     = 1; % all labile detritus goes to NH4
new_BioenergeticBudget(1:3, looky_ULTIMATEdetritus)         = 0;
new_BioenergeticBudget(3, looky_ULTIMATEdetritus)        	= 1; % all ULTIMATE detritus goes to NH4
new_BioenergeticBudget(1, looky_terminalBnthDetr)         	= 1; % all terminal benthic detritus goes to production
new_BioenergeticBudget(2:3, looky_terminalBnthDetr)        	= 0; % all terminal benthic detritus goes to production


% BioenergeticBudget_ProductionDetail -------------------------------------
%   ECOTRAN.BioenergeticBudget_ProductionDetail (sum of each clm = ECOTRAN.BioenergeticBudget_production
%           row 1 = BioenergeticBudget_SumPredation (total consumption of each group p going to all its consumers)
%           row 2 = BioenergeticBudget_eggs (total consumption of each group p going to eggs, gametes, or live births)
%           row 3 = BioenergeticBudget_OtherMortality (total consumption of each group p going to 
%           row 4 = BioenergeticBudget_BA (total consumption of each group p going to biomass accumulation)
%           row 5 = BioenergeticBudget_EM (total consumption of each group p going to emigration)
% % % new_BioenergeticBudget_ProductionDetail(1:5, looky_labileBnthDetr)  = 0; % add clm for labile benthic detritus
new_BioenergeticBudget_ProductionDetail(1:5, looky_ULTIMATEdetritus)	= 0; % add clm for ULTIMATE detritus
new_BioenergeticBudget_ProductionDetail(:, looky_terminalBnthDetr)      = new_BioenergeticBudget_ProductionDetail(:, looky_terminalBnthDetr) ./ sum(new_BioenergeticBudget_ProductionDetail(:, looky_terminalBnthDetr));


% BioenergeticBudget_OtherMortDetail --------------------------------------
%   ECOTRAN.BioenergeticBudget_OtherMortDetail
%           row 1 = flow to terminal pelagic detritus
%           row 2 = flow to terminal benthic detritus
% % % new_BioenergeticBudget_OtherMortDetail(1:2, looky_labileBnthDetr)	= 0;
new_BioenergeticBudget_OtherMortDetail(1:2, looky_ULTIMATEdetritus)     = 0;
new_BioenergeticBudget_OtherMortDetail(1:2, looky_terminalBnthDetr)     = 0;


% BioenergeticBudget_FecesDetail ------------------------------------------
%   ECOTRAN.BioenergeticBudget_FecesDetail
%           row 1 = flow to terminal pelagic detritus
%           row 2 = flow to terminal benthic detritus
% % % new_BioenergeticBudget_FecesDetail(1:2, looky_labileBnthDetr)       = 0;
new_BioenergeticBudget_FecesDetail(1:2, looky_ULTIMATEdetritus)         = 0;
new_BioenergeticBudget_FecesDetail(:, looky_terminalBnthDetr)           = 0;


% ProductionBudget --------------------------------------------------------
%   ECOTRAN.ProductionBudget (each clm sums to 1; negative values are allowed)
%           row 1 = ProductionBudget_predation (total production of each group p going to the sum of all predation pressure on each group p)
%           row 2 = ProductionBudget_eggs (total production of each group p going to eggs, gametes, or live births)
%           row 3 = ProductionBudget_OtherMortality
%           row 4 = ProductionBudget_BA
%           row 5 = ProductionBudget_EM
% % % new_ProductionBudget(1:5, looky_labileBnthDetr)                     = 0;
new_ProductionBudget(1:5, looky_ULTIMATEdetritus)                       = 0;


% ProductionBudget_OtherMortDetail ----------------------------------------
%   ECOTRAN.ProductionBudget_OtherMortDetail
%           row 1 = flow to terminal pelagic detritus
%           row 2 = flow to terminal benthic detritus
% % % new_ProductionBudget_OtherMortDetail(1:2, looky_labileBnthDetr)     = 0;
new_ProductionBudget_OtherMortDetail(1:2, looky_ULTIMATEdetritus)       = 0;


% GroupType ---------------------------------------------------------------
% % % GroupTypeDef_labileBnthDetr                                                 = 4.9;
% % % GroupType_BAEM                                                              = new_GroupType([looky_BA looky_EM]);
% % % new_GroupType(looky_labileBnthDetr)                                         = GroupTypeDef_labileBnthDetr;
% % % new_GroupType([(looky_BA + num_LabileDetritus) (looky_EM + num_LabileDetritus)]) = GroupType_BAEM;
GroupTypeDef_ULTIMATEdetritus                                          	= 4.9;
GroupType_BAEM                                                        	= new_GroupType([looky_BA looky_EM]);
new_GroupType(looky_ULTIMATEdetritus)                                	= GroupTypeDef_ULTIMATEdetritus;
new_GroupType([(looky_BA + num_ULTIMATEdetritus) (looky_EM + num_ULTIMATEdetritus)])    = GroupType_BAEM;


% misc ECOTRAN variables --------------------------------------------------
% % % looky_DETRITUS                                                              = find(floor(new_GroupType) == original_ECOTRAN.GroupTypeDef_ANYDetritus);
% % % new_GroupType_detritus                                                      = new_GroupType(looky_DETRITUS);
% % % new_AggLabel_detritus                                                       = new_AggLabel(looky_DETRITUS);
% % % new_TransferEfficiency(looky_labileBnthDetr)                                = 1; % set to 1 as a default; TE is written over in dynamic code and in structural scenario code
% % % new_ProductionLossScaler((looky_labileBnthDetr-num_nutrients))              = 0; % its a benthic group not impacted by advection
% % % new_RetentionScaler((looky_labileBnthDetr-num_nutrients))                   = 1; % its a benthic group not impacted by advection
% % % new_FunctionalResponseParams(:, (looky_labileBnthDetr-num_nutrients))       = 0; % set to 0 to make labile benthic detritus trophic responses linear
looky_DETRITUS                                                              = find(floor(new_GroupType) == original_ECOTRAN.GroupTypeDef_ANYDetritus);
new_GroupType_detritus                                                      = new_GroupType(looky_DETRITUS);
new_AggLabel_detritus                                                       = new_AggLabel(looky_DETRITUS);
new_TransferEfficiency(looky_ULTIMATEdetritus)                            	= 1; % set to 1 as a default; TE is written over in dynamic code and in structural scenario code
new_ProductionLossScaler((looky_ULTIMATEdetritus - num_nutrients))        	= 0; % its a benthic group not impacted by advection
new_RetentionScaler((looky_ULTIMATEdetritus - num_nutrients))            	= 1; % its a benthic group not impacted by advection
new_FunctionalResponseParams(:, (looky_ULTIMATEdetritus - num_nutrients))   = 0; % set to 0 to make ULTIMATE detritus trophic responses linear


% EwE variables -----------------------------------------------------------
% % % new_EwE_Biomass(looky_labileBnthDetr)                               = new_EwE_Biomass(looky_terminalBnthDetr); % assume same as terminal benthic detritus; biomass for this group is arbitrary
% % % new_EwE_PB(looky_labileBnthDetr)                                    = new_EwE_PB(looky_terminalBnthDetr); % assume same as terminal benthic detritus; PB for this group is arbitrary QQQ ???
% % % new_EwE_QB(looky_labileBnthDetr)                                    = new_EwE_QB(looky_terminalBnthDetr); % assume same as terminal benthic detritus; PB for this group is arbitrary QQQ ???
% % % new_EwE_PQ(looky_labileBnthDetr)                                    = 1; % PQ for detritus = 1
% % % new_EwE_AE(looky_labileBnthDetr)                                    = 1; % AE for detritus = 1
% % % new_EwE_BA(looky_labileBnthDetr)                                    = new_EwE_BA(looky_terminalBnthDetr); % assume same as terminal benthic detritus
% % % new_EwE_EM(looky_labileBnthDetr)                                    = new_EwE_EM(looky_terminalBnthDetr); % assume same as terminal benthic detritus
new_EwE_Biomass(looky_ULTIMATEdetritus)                               = new_EwE_Biomass(looky_terminalBnthDetr); % assume same as terminal benthic detritus; biomass for this group is arbitrary
new_EwE_PB(looky_ULTIMATEdetritus)                                    = new_EwE_PB(looky_terminalBnthDetr); % assume same as terminal benthic detritus; PB for this group is arbitrary QQQ ???
new_EwE_QB(looky_ULTIMATEdetritus)                                    = new_EwE_QB(looky_terminalBnthDetr); % assume same as terminal benthic detritus; PB for this group is arbitrary QQQ ???
new_EwE_PQ(looky_ULTIMATEdetritus)                                    = 1; % PQ for detritus = 1
new_EwE_AE(looky_ULTIMATEdetritus)                                    = 1; % AE for detritus = 1
new_EwE_BA(looky_ULTIMATEdetritus)                                    = new_EwE_BA(looky_terminalBnthDetr); % assume same as terminal benthic detritus
new_EwE_EM(looky_ULTIMATEdetritus)                                    = new_EwE_EM(looky_terminalBnthDetr); % assume same as terminal benthic detritus


% fate variables ----------------------------------------------------------
% % % new_DetritusFate_feces(:, looky_labileBnthDetr)                     = new_DetritusFate_feces(:, looky_terminalBnthDetr); % assume same as terminal benthic detritus; PB for this group is arbitrary QQQ ???
% % % new_DetritusFate_senescence(:, looky_terminalBnthDetr)                  = 0; % set to 0 as all senenscence now goes to labile benthic detritus
% % % new_DetritusFate_senescence(:, looky_labileBnthDetr)                = 0; % assume 0 as 100% directed to NH4
% % % new_ExcretionFate(:, looky_labileBnthDetr)                          = 0;
% % % new_ExcretionFate(2, looky_labileBnthDetr)                          = 1; % labile benthic detritus NH4 goes to sub-surface box; terminal benthic detritus metaboilsm has been switched off (so its fate doesn't matter)
% % % new_EggFate(:, looky_labileBnthDetr)                                = 0;
new_DetritusFate_feces(:, looky_ULTIMATEdetritus)                       = new_DetritusFate_feces(:, looky_terminalBnthDetr); % assume same as terminal benthic detritus; PB for this group is arbitrary QQQ ???
new_DetritusFate_senescence(:, looky_terminalBnthDetr)                  = 0; % set to 0 as all senenscence now goes to ULTIMATE detritus
new_DetritusFate_senescence(:, looky_ULTIMATEdetritus)                  = 0; % assume 0 as 100% directed to NH4
new_ExcretionFate(:, looky_ULTIMATEdetritus)                            = 0;
new_ExcretionFate(2, looky_ULTIMATEdetritus)                            = 1; % ULTIMATE detritus NH4 goes to sub-surface box; terminal benthic detritus metaboilsm has been switched off (so its fate doesn't matter)
new_EggFate(:, looky_ULTIMATEdetritus)                                  = 0;


% fishery variables -------------------------------------------------------
% % % new_EwE_Landings(looky_labileBnthDetr)                              = 0;
% % % new_EwE_Discards(looky_labileBnthDetr)                              = 0;
% % % new_EwE_TotalFishery(looky_labileBnthDetr)                          = 0;
new_EwE_Landings(looky_ULTIMATEdetritus)                                = 0;
new_EwE_Discards(looky_ULTIMATEdetritus)                                = 0;
new_EwE_TotalFishery(looky_ULTIMATEdetritus)                            = 0;


% update EnergyBudget_matrix ----------------------------------------------
new_EnergyBudget_matrix(new_num_E2Egroups, new_E2E_clms)                = 0; % append new row(s) and clm(s)
new_CV_EnergyBudget_matrix(new_num_E2Egroups, new_E2E_clms)             = 0; % append new row(s) and clm(s)


% put flow from bacterial metabolism of detritus pool(s) to appropriate NH4 pool(s)
% % % new_EnergyBudget_matrix(looky_bnthNH4, looky_labileBnthDetr)        = 1; % assume 100%, and use TE to adjust bacterial recycling rate
% % % new_CV_EnergyBudget_matrix(looky_bnthNH4, looky_labileBnthDetr)     = PEDIGREE_BacterialMTBLSM;
new_EnergyBudget_matrix(looky_bnthNH4, looky_ULTIMATEdetritus)          = 1; % assume 100%, and use TE to adjust bacterial recycling rate
new_CV_EnergyBudget_matrix(looky_bnthNH4, looky_ULTIMATEdetritus)       = PEDIGREE_BacterialMTBLSM;


% remove NH4 flow from terminal benthic detritus --------------------------
NH4_TerminalBenthicDetritus                                                         = sum(new_EnergyBudget_matrix([looky_plgcNH4 looky_bnthNH4], looky_terminalBnthDetr));
new_EnergyBudget_matrix([looky_plgcNH4 looky_bnthNH4], looky_terminalBnthDetr)      = 0;
new_EnergyBudget_matrix(:, looky_terminalBnthDetr)                                  = new_EnergyBudget_matrix(:, looky_terminalBnthDetr) / sum(new_EnergyBudget_matrix(:, looky_terminalBnthDetr));
new_CV_EnergyBudget_matrix([looky_plgcNH4 looky_bnthNH4], looky_terminalBnthDetr)   = 0;


% add detritus flow from terminal benthic detritus to labile benthic detritus
% % % new_EnergyBudget_matrix(:, looky_terminalBnthDetr)                           = new_EnergyBudget_matrix(:, looky_terminalBnthDetr) * new_EcotrophicEfficiency_predation(looky_terminalBnthDetr);
% % % new_EnergyBudget_matrix(looky_labileBnthDetr, looky_terminalBnthDetr)    = 1 - new_EcotrophicEfficiency_predation(looky_terminalBnthDetr);
% % % new_CV_EnergyBudget_matrix(looky_labileBnthDetr, looky_terminalBnthDetr) = PEDIGREE_BacterialMTBLSM; % QQQ set to 0 since this is always 100%???
new_EnergyBudget_matrix(:, looky_terminalBnthDetr)                                  = new_EnergyBudget_matrix(:, looky_terminalBnthDetr) * new_EcotrophicEfficiency_predation(looky_terminalBnthDetr);
new_EnergyBudget_matrix(looky_ULTIMATEdetritus, looky_terminalBnthDetr)             = 1 - new_EcotrophicEfficiency_predation(looky_terminalBnthDetr);
new_CV_EnergyBudget_matrix(looky_ULTIMATEdetritus, looky_terminalBnthDetr)          = PEDIGREE_BacterialMTBLSM; % could set to 0 since this is always 100%???


% update ECOTRAN_PEDIGREE.CV_ConsumptionBudget ----------------------------
%   ECOTRAN consumption budget (as fraction of total consumption), by row:
%   	feces
%       metabolism
%       eggs
%       predation
%       senescence
%       BA
%       EM
% % % new_CV_ConsumptionBudget(1:7, looky_labileBnthDetr)                     = 0; % add labile benthic detritus clm; all terms in clm are CV = 0 as 100% always goes to NH4
% % % new_CV_ConsumptionBudget(1:7, looky_labileBnthDetr)                     = 0; % add labile benthic detritus clm; all terms in clm are CV = 0 as 100% always goes to NH4
new_CV_ConsumptionBudget(1:7, looky_ULTIMATEdetritus)                     = 0; % add ULTIMATE detritus clm; all terms in clm are CV = 0 as 100% always goes to NH4
new_CV_ConsumptionBudget(1:7, looky_ULTIMATEdetritus)                     = 0; % add ULTIMATE detritus clm; all terms in clm are CV = 0 as 100% always goes to NH4


% update ECOTRAN_PEDIGREE.ECTRN_ConsumptionBudget -------------------------
%   ECOTRAN consumption budget (as fraction of total consumption), by row:
%   	feces
%       metabolism
%       eggs
%       predation
%       senescence
%       BA
%       EM
new_ECTRN_ConsumptionBudget(1:2, :)                         = new_BioenergeticBudget(2:3, :);                   % feces & metabolism
new_ECTRN_ConsumptionBudget(3, :)                           = new_BioenergeticBudget_ProductionDetail(2, :);    % eggs
new_ECTRN_ConsumptionBudget(4, :)                           = new_BioenergeticBudget_ProductionDetail(1, :);    % predation
new_ECTRN_ConsumptionBudget(5, :)                           = new_BioenergeticBudget_ProductionDetail(3, :);    % senescence
new_ECTRN_ConsumptionBudget(6:7, :)                         = new_BioenergeticBudget_ProductionDetail(4:5, :);	% BA & EM


% update other ECOTRAN_PEDIGREE parameters --------------------------------
looky_NonPredation                                          = [looky_AllNutrients; looky_eggs; looky_DETRITUS];
looky_predation                                             = 1:new_num_E2Egroups;
looky_predation(looky_NonPredation)                         = [];





% *************************************************************************
% STEP 3: pack up results--------------------------------------------------
ECOTRAN.EnergyBudget_matrix                                 = new_EnergyBudget_matrix;
ECOTRAN.BioenergeticBudget                                  = new_BioenergeticBudget;
ECOTRAN.BioenergeticBudget_ProductionDetail                 = new_BioenergeticBudget_ProductionDetail;
ECOTRAN.BioenergeticBudget_OtherMortDetail                  = new_BioenergeticBudget_OtherMortDetail;
ECOTRAN.BioenergeticBudget_FecesDetail                      = new_BioenergeticBudget_FecesDetail;
ECOTRAN.ProductionBudget                                    = new_ProductionBudget;
ECOTRAN.ProductionBudget_OtherMortDetail                    = new_ProductionBudget_OtherMortDetail;
ECOTRAN.GroupType                                           = new_GroupType;
ECOTRAN.AggLabel                                            = new_AggLabel;
ECOTRAN.GroupType_detritus                                  = new_GroupType_detritus;
ECOTRAN.AggLabel_detritus                                   = new_AggLabel_detritus;
ECOTRAN.EwE_Biomass                                         = new_EwE_Biomass;
ECOTRAN.EwE_PB                                              = new_EwE_PB;
ECOTRAN.EwE_QB                                              = new_EwE_QB;
ECOTRAN.EwE_PQ                                              = new_EwE_PQ;
ECOTRAN.EwE_AE                                              = new_EwE_AE;
ECOTRAN.EwE_BA                                              = new_EwE_BA;
ECOTRAN.EwE_EM                                              = new_EwE_EM;
ECOTRAN.DetritusFate_feces                                  = new_DetritusFate_feces;
ECOTRAN.DetritusFate_senescence                             = new_DetritusFate_senescence;
ECOTRAN.ExcretionFate                                       = new_ExcretionFate;
ECOTRAN.EggFate                                             = new_EggFate;
ECOTRAN.EwE_Landings                                        = new_EwE_Landings;
ECOTRAN.EwE_Discards                                        = new_EwE_Discards;
ECOTRAN.EwE_TotalFishery                                    = new_EwE_TotalFishery;
ECOTRAN.EcotrophicEfficiency_predation                      = new_EcotrophicEfficiency_predation;
ECOTRAN.EcotrophicEfficiency_BA                             = new_EcotrophicEfficiency_BA;
ECOTRAN.EcotrophicEfficiency_EM                             = new_EcotrophicEfficiency_EM;
ECOTRAN.EcotrophicEfficiency                                = new_EcotrophicEfficiency;
ECOTRAN.TransferEfficiency                                  = new_TransferEfficiency;
ECOTRAN.ProductionLossScaler                                = new_ProductionLossScaler;
ECOTRAN.RetentionScaler                                     = new_RetentionScaler;
ECOTRAN.FunctionalResponseParams                            = new_FunctionalResponseParams;

ECOTRAN.GroupTypeDef_ANYNitroNutr                           = original_ECOTRAN.GroupTypeDef_ANYNitroNutr;
ECOTRAN.GroupTypeDef_NO3                                    = original_ECOTRAN.GroupTypeDef_NO3;
ECOTRAN.GroupTypeDef_plgcNH4                                = original_ECOTRAN.GroupTypeDef_plgcNH4;
ECOTRAN.GroupTypeDef_bnthNH4                                = original_ECOTRAN.GroupTypeDef_bnthNH4;
ECOTRAN.GroupTypeDef_ANYPrimaryProd                         = original_ECOTRAN.GroupTypeDef_ANYPrimaryProd;
ECOTRAN.GroupTypeDef_LrgPhyto                               = original_ECOTRAN.GroupTypeDef_LrgPhyto;
ECOTRAN.GroupTypeDef_SmlPhyto                               = original_ECOTRAN.GroupTypeDef_SmlPhyto;
ECOTRAN.GroupTypeDef_Macrophytes                            = original_ECOTRAN.GroupTypeDef_Macrophytes;
ECOTRAN.GroupTypeDef_ANYConsumer                            = original_ECOTRAN.GroupTypeDef_ANYConsumer;
ECOTRAN.GroupTypeDef_ConsumPlgcPlankton                     = original_ECOTRAN.GroupTypeDef_ConsumPlgcPlankton;
ECOTRAN.GroupTypeDef_ConsumPlgcNekton                       = original_ECOTRAN.GroupTypeDef_ConsumPlgcNekton;
ECOTRAN.GroupTypeDef_ConsumPlgcWrmBlood                     = original_ECOTRAN.GroupTypeDef_ConsumPlgcWrmBlood;
ECOTRAN.GroupTypeDef_ConsumBntcInvert                       = original_ECOTRAN.GroupTypeDef_ConsumBntcInvert;
ECOTRAN.GroupTypeDef_ConsumBntcVert                         = original_ECOTRAN.GroupTypeDef_ConsumBntcVert;
ECOTRAN.GroupTypeDef_ConsumBnthWrmBlood                     = original_ECOTRAN.GroupTypeDef_ConsumBnthWrmBlood;
ECOTRAN.GroupTypeDef_eggs                                   = original_ECOTRAN.GroupTypeDef_eggs;
ECOTRAN.GroupTypeDef_offal                                  = original_ECOTRAN.GroupTypeDef_offal;
ECOTRAN.GroupTypeDef_terminalPlgcDetr                       = original_ECOTRAN.GroupTypeDef_terminalPlgcDetr;
ECOTRAN.GroupTypeDef_terminalBnthDetr                       = original_ECOTRAN.GroupTypeDef_terminalBnthDetr;
% % % ECOTRAN.GroupTypeDef_labileBnthDetr                         = GroupTypeDef_labileBnthDetr;
ECOTRAN.GroupTypeDef_ULTIMATEdetritus                       = GroupTypeDef_ULTIMATEdetritus;
ECOTRAN.GroupTypeDef_ANYDetritus                            = original_ECOTRAN.GroupTypeDef_ANYDetritus;
ECOTRAN.GroupTypeDef_BA                                     = original_ECOTRAN.GroupTypeDef_BA;
ECOTRAN.GroupTypeDef_EM                                     = original_ECOTRAN.GroupTypeDef_EM;
ECOTRAN.GroupTypeDef_fishery                                = original_ECOTRAN.GroupTypeDef_fishery;
ECOTRAN.GroupTypeDef_import                                 = original_ECOTRAN.GroupTypeDef_import;
ECOTRAN.GroupTypeDef_plgcBacteria                           = original_ECOTRAN.GroupTypeDef_plgcBacteria;
ECOTRAN.GroupTypeDef_bnthBacteria                           = original_ECOTRAN.GroupTypeDef_bnthBacteria;


ECOTRAN_PEDIGREE.CV_EnergyBudget_matrix                     = new_CV_EnergyBudget_matrix;
ECOTRAN_PEDIGREE.ECTRN_ConsumptionBudget                    = new_ECTRN_ConsumptionBudget;
ECOTRAN_PEDIGREE.CV_ConsumptionBudget                       = new_CV_ConsumptionBudget;
ECOTRAN_PEDIGREE.looky_AllNutrients                         = looky_AllNutrients;
ECOTRAN_PEDIGREE.looky_detritus                             = looky_DETRITUS;
ECOTRAN_PEDIGREE.looky_eggs                                 = looky_eggs;
ECOTRAN_PEDIGREE.looky_predation                            = looky_predation;
ECOTRAN_PEDIGREE.looky_fishery                              = looky_fishery;
ECOTRAN_PEDIGREE.looky_PelagicDetritus                      = looky_terminalPlgcDetr;
ECOTRAN_PEDIGREE.looky_BenthicDetritus                      = looky_terminalBnthDetr;
% % % ECOTRAN_PEDIGREE.looky_labileBnthDetr                       = looky_labileBnthDetr;
ECOTRAN_PEDIGREE.looky_ULTIMATEdetritus                     = looky_ULTIMATEdetritus;


% end m-file---------------------------------------------------------------