function randomEwE = f_EE_MonteCarlo_04092014(randomEwE)
% calculate EE for MonteCarlo EwE models
% by Jim Ruzicka
% takes:
%       randomEwE.Consumption
%       randomEwE.TotalFisheries
%       randomEwE.Biomass
%       randomEwE.Production
%       randomEwE.BA
%       randomEwE.EM
%       randomEwE.GroupType
%       randomEwE.GroupTypeDef_ANYDetritus
% returns:
%       randomEwE.EcotrophicEfficiency_predation    (vertical vector)
%       randomEwE.EcotrophicEfficiency_BA           (vertical vector)
%       randomEwE.EcotrophicEfficiency_EM           (vertical vector)
%       randomEwE.EcotrophicEfficiency              (vertical vector)
% calls:
%       none
% revision date: 4-9-2014





% *************************************************************************
% STEP 1: load variable structures (don't alter original values)-----------
Consumption              = randomEwE.Consumption;
TotalFisheries           = randomEwE.TotalFisheries;
Biomass                  = randomEwE.Biomass; % (t/km2) (vertical vector)
Production               = randomEwE.Production;
BA                       = randomEwE.BA;
EM                       = randomEwE.EM;
GroupType                = randomEwE.GroupType;
GroupTypeDef_ANYDetritus = randomEwE.GroupTypeDef_ANYDetritus;
GroupTypeDef_eggs        = randomEwE.GroupTypeDef_eggs;
looky_detritus           = randomEwE.looky_detritus; % includes eggs



% *************************************************************************
% STEP 2: correct detritus terms-------------------------------------------
Consumption(:, looky_detritus) = 0; % set detritus clms to 0 in Consumption (don't include flow to detritus as predation)
EM(looky_detritus)             = 0; % set detritus rows to 0



% QQQ remove cannibalism???
% Consumption(logical(eye(size(Consumption)))) = 0;
% QQQ what about production??? is it PB * B??? or made from consumption matriz???

% *************************************************************************
% STEP 3: calculate total predation & fishing pressure on each group-------
TotalPredation  = sum(Consumption(1:(end-1), :), 2); % total predation on each group (trimming off import consumption row); does NOT include flow to detritus
TotalPredation  = TotalPredation + sum(TotalFisheries, 2); % add Landings + Discards to TotalPredation





% *************************************************************************
% STEP 4: Ecotrophic Efficiencies (distribution of production)-------------
EcotrophicEfficiency_predation    = TotalPredation ./ Production; % (M2_j / P_j) = fraction of production by each group, j, passed upwards in food web via predation; note omission of cannibalism;
EcotrophicEfficiency_BA           = BA             ./ Production; % (BA_j / P_j) = fraction of production by each group, j, directed to biomass accumulation;
EcotrophicEfficiency_EM           = EM             ./ Production; % (EM_j / P_j) = fraction of production by each group, j, directed to emigration (immigration is negative production);
EcotrophicEfficiency              = EcotrophicEfficiency_predation + EcotrophicEfficiency_BA + EcotrophicEfficiency_EM; % (EE_j = (M2_j + EM_j + BA_j) / P_j) = Ecotrophic Efficiency as defined by EwE; note that the omission of cannibalism from the total predation term corrects the EcotrophicEfficiency for the omission of cannibalism in the PredationMatrix (calculated below)





% *************************************************************************
% STEP 5: pack results for export------------------------------------------
randomEwE.EcotrophicEfficiency_predation    = EcotrophicEfficiency_predation;
randomEwE.EcotrophicEfficiency_BA           = EcotrophicEfficiency_BA; % Biomass Accumulation (local production)
randomEwE.EcotrophicEfficiency_EM           = EcotrophicEfficiency_EM; % emigration
randomEwE.EcotrophicEfficiency              = EcotrophicEfficiency;





% end m-file***************************************************************