% ECOTRANdynamic_context_basin_08032018
% run a dynamic, 5-box model over time
% use with basin physics
% by Jim Ruzicka
% calls:
%           f_read_EwE_csv_02022016                     read in ECOPATH (EwE) model from VisualBasic .csv file and store as variable 'dat'; (use for VisualBasic food web files with 5 primary producers)
%           f_AggregateResults_EwE_03122015             prepare EwE model for use by ECOTRAN; also aggregate functional groups here if wanted
%           ECOTRANuncertainty_05062016                 generate an ECOTRAN (E2E) model; the heart of ECOTRAN
%                   f_ECOfunction_05142015              returns a single ECOTRAN model for 1 "type" EwE model or 1 Monte Carlo EwE model
%                   f_RedistributeCannibalism           remove cannibalism terms on diagonal of EwE_diet matrix
%                   f_CalcPredationMatrix               for each producer, p, and consumer, c: ((b_pc * Q_c) / M2_p)) = the fraction of total predation on each producer, p, going to each consumer, c
%           f_E2E_pedigree_08032018                     calculate uncertainty terms for all elements of the ECOTRAN EnergyBudget_matrix (A_cp) as Coefficients of Variation (CV)
%           f_TerminalDetritus_08032018                 add a final ULTIMATE detritus pool; necessary for management of bacterial metabolism of terminal benthic detritus in time-dynamic simulations
%           f_E2E_MonteCarlo_08032018                   generate a set of randomly generated ECOTRAN models, multiple alternate versions of the EnergyBudget_matrix (A_cp); model 1 of the stack is the "type" model defined by the parameters of the VisualBasic .csv file
%           f_OrdinalDate                               calculate ordinal dates; day of year with January 1 of any year = 1
%           f_ECOTRANphysics_basin_08022018             BASIN system: define the physical geometry of the model and prepare physical advection, mixing, and sinking rate time-series; (rates from M. Heath)
%               round2                                  round to a specified number of decimal places
%               f_LightIntensity                        solar light intensity for given location and time
%           f_SeasonalPB_PrimaryProducers               (deactivated)
%           f_FunctionalResponse_MonteCarlo_09122016    prepare array of vulnerability terms and allows for random generation of functional response terms within a predefined uncertainty level
%           f_MichaelisMenten_05152016                  (optional) phytoplankton uptake rate of NO3 & NH4 (mmole N/m3/d) & p/b @ t as calculated from Michaelis-Menten uptake kinetics
%           f_InitialProductionRates_05112016          	calculate initial or mean production conditions
%               f_WebProductivityWLoss                  calculate production rates of all groups under a given driver (e.g., NO3 or primary production); also accounts for defined rates of group production export when running static scenarios
%           f_StaticProductionTimeseries_09042017       calculate production rates for all model groups under a given driver (NO3) input rate; use for ocean boundary conditions
%               f_WebProductivityWLoss                  calculate production rates of all groups under a given driver (e.g., NO3 or primary production); also accounts for defined rates of group production export when running static scenarios
%       ODE (2 options):
%           1) f_ECOTRANode_ReflectiveBoundary_basin_05242017   (use this for getting soln at each time-point; for reflective boundary conditions)
%           2) f_ECOTRANode_DefinedBoundary_basin_08032017      (use this for getting soln at each time-point; for defined boundary or empty ocean conditions)
% returns:
%       store_T                     time-series of day umbers
%       store_ProductionRates       time-series of production rates for each functional group; (t/km2/d) 
%
% NOTE: code cannot currently accomodate seasonal changes in flows to non-terminal detritus pools (e.g., fisheries and detritus columns of EnergyBudget_matrix)
% revision date: 8-3-2018


% *************************************************************************
% STEP 1: load & aggregate EwE results-------------------------------------
% step 1a: define food web model to use -----------------------------------

ReadFile_directory      = '/Users/ruzickaj/Documents/ECOTRAN_08052018/FoodWeb_models/ComparativeShelves_models/';
readFile                = 'NCC_NSFagg_G_8-10-2016_B.csv';

% ReadFile_directory      = '/Users/ruzickaj/Documents/ECOTRAN_08052018/FoodWeb_models/ComparativeShelves_models/';
% readFile                = 'CGoA_NSFagg_E_08102016_B.csv'; % without labile detritus

% ReadFile_directory      = '/Users/ruzickaj/Documents/ECOTRAN_08052018/FoodWeb_models/ComparativeShelves_models/';
% readFile                = 'GB_NSFagg_P_02082017.csv';

% ReadFile_directory      = '/Users/ruzickaj/Documents/ECOTRAN_08052018/FoodWeb_models/ComparativeShelves_models/';
% readFile                = 'NorSea_NSFagg_G_9-18-2016.csv';

readFile                = [ReadFile_directory readFile];

% step 1b: load ECOPATH (EwE) model from Aydin VisualBasic file (.csv format)
[dat]                   = f_read_EwE_csv_02022016(readFile);

% step 1c: aggregate model results & prep EwEResult for analysis ----------
[EwEResult, PEDIGREE]   = f_AggregateResults_EwE_03122015(dat);

% step 1d: define filename and directory for saving results ---------------
SaveFile_directory = '/Users/ruzickaj/Documents/ECOTRAN_08052018/TimeDynamic_simulations/';
SaveFile_label     = 'NCCweb_basin_stndPEDIGREE';





% *************************************************************************
% STEP 2: load pre-generated Monte Carlo EwE models------------------------
% step 2a: Identify Monte Carlo method ------------------------------------
%          method 1: PREFERRED METHOD --> start with the one original ECOTRAN base model and generate a set of Monte Carlo E2E models of the ECOTRAN production matrix using a predefined CV (or defualt pedigree CV = 0.5)
%          method 2: use pre-generated Monte Carlo EwE models, convert to ECOTRAN E2E models, and run scenarios directly on EACH of these individually
%                    (each matrix being its own base model and scenario model)
MonteCarlo_method           = 1;    % SSS; choose 1 or 2; NOTE: method 2 is no longer supported
use_MonteCarlo              = 'y';  % SSS; use MonteCarlo uncertainty estimates?

% step 2b: if method 2 is chosen, load MonteCarloSet ----------------------
if strcmp(use_MonteCarlo, 'y') && MonteCarlo_method == 2
    
    % define MonteCarloSet  = name of Monte Carlo results with file directory (loads 'MonteCarloStore')
    MonteCarloSet_FileDirectory = '';   % NOTE laptop MAC directory format
    MonteCarloSet               = '';   % sampling interval = +/1 1 STD sampling (1 std in denominator)
    MonteCarloSet               = [MonteCarloSet_FileDirectory MonteCarloSet];
    
    load(MonteCarloSet, 'MonteCarloStore')
else
    MonteCarloStore          = [];
end





% *************************************************************************
% STEP 3: ECOTRAN conversion-----------------------------------------------
% step 3a: perform ECOTRAN conversion -------------------------------------
[ECOTRAN]                                       = ECOTRANuncertainty_05062016(EwEResult, MonteCarloStore);





% *************************************************************************
% STEP 4: Generate E2E Monte Carlo models based on ECOTRAN EnergyBudget_matrix
%         NOTE: this is Monte Carlo method 1
%         method 1: start with the one original ECOTRAN base model and generate a set of Monte Carlo E2E models of the ECOTRAN production matrix using a predefined CV (or defualt pedigree CV = 0.5)
num_webMonteCarlo                                           = 25; % SSS set this value
if strcmp(use_MonteCarlo, 'y') && MonteCarlo_method == 1
    
    PEDIGREE.PEDIGREE_eggs                                  = 0.1; % SSS egg pedigree for all groups (CV)
    PEDIGREE.PEDIGREE_predation                             = 0.1; % SSS predation pedigree for all groups (CV)
    PEDIGREE.PEDIGREE_senescence                            = 0.1; % SSS senescence pedigree for all groups (CV)
    PEDIGREE.PEDIGREE_BacterialMTBLSM                       = 0.1; % SSS pedigree for implicit bacterial metabolism of terminal detritus (CV)
    PEDIGREE.PEDIGREE_NutrientUptake                        = 0.1; % SSS pedigree for nutrient uptake by primary producers (CV)
    ECOTRAN_PEDIGREE                                        = f_E2E_pedigree_08032018(EwEResult, PEDIGREE, ECOTRAN);
    
            % SSS use for standardized pedigree
            %     overwrite the pedigree values from the ECOPATH (EwE) model from VisualBasic file (.csv format)
            [rows, clms]                                = size(ECOTRAN_PEDIGREE.CV_EnergyBudget_matrix);
            ECOTRAN_PEDIGREE.CV_EnergyBudget_matrix     = 1 * ones(rows, clms);
            ECOTRAN_PEDIGREE.CV_ConsumptionBudget       = zeros(7, clms);
            ECOTRAN_PEDIGREE.CV_ConsumptionBudget(1, :) = 0.5; % feces
            ECOTRAN_PEDIGREE.CV_ConsumptionBudget(2, :) = 0.5; % metabolism
            ECOTRAN_PEDIGREE.CV_ConsumptionBudget(3, :) = 0.5; % eggs
            ECOTRAN_PEDIGREE.CV_ConsumptionBudget(4, :) = 0.5; % predation
            ECOTRAN_PEDIGREE.CV_ConsumptionBudget(5, :) = 0.5; % senescence
            ECOTRAN_PEDIGREE.CV_ConsumptionBudget(6, :) = 0.5; % BA
            ECOTRAN_PEDIGREE.CV_ConsumptionBudget(7, :) = 0.5; % EM
    
    [ECOTRAN, ECOTRAN_PEDIGREE]                             = f_TerminalDetritus_08032018(ECOTRAN, ECOTRAN_PEDIGREE);   % add a final ULTIMATE detritus pool; necessary for management of bacterial metabolism of terminal benthic detritus in time-dynamic simulations
    MonteCarloConditions.num_trials                         = num_webMonteCarlo;          	% number of trials to run
    MonteCarloConditions.EnergyBudget_matrix                = ECOTRAN.EnergyBudget_matrix;
    MonteCarloConditions.DistributionType                   = 'normal';                 	% 'normal' or 'uniform'; (NOTE: code not fully proofed for uniform)
    [ConsumptionBudget_MonteCarlo, EnergyBudget_MonteCarlo] = f_E2E_MonteCarlo_08032018(MonteCarloConditions, ECOTRAN_PEDIGREE);
    EnergyBudget_matrix                                     = EnergyBudget_MonteCarlo;
    E2E_layers                                              = MonteCarloConditions.num_trials;

end % (choose MonteCarlo_method)


% step 4b: read in ECOTRAN structure variables ----------------------------
%          (so that no changes made to original values)
GroupType                                        = ECOTRAN.GroupType;
AggLabel                                         = ECOTRAN.AggLabel;
% EnergyBudget_matrix                              = ECOTRAN.EnergyBudget_matrix;
EwE_Biomass                                      = ECOTRAN.EwE_Biomass;         % note inclusion of separately constructed regional models
EwE_PB                                           = ECOTRAN.EwE_PB;
EwE_QB                                           = ECOTRAN.EwE_QB;
DetritusFate_feces                               = ECOTRAN.DetritusFate_feces;
DetritusFate_senescence                          = ECOTRAN.DetritusFate_senescence;
ExcretionFate                                    = ECOTRAN.ExcretionFate;
EggFate                                          = ECOTRAN.EggFate;
ProductionLossScaler                             = ECOTRAN.ProductionLossScaler;
RetentionScaler                                  = ECOTRAN.RetentionScaler;     % sensitivity to advection & mixing (0 = more advection <--> less advection =1); (horizontal vector; without nutrient clms)
FunctionalResponseParams                         = ECOTRAN.FunctionalResponseParams;
[num_E2Egroups, E2E_clms, num_webMonteCarlo]        = size(EnergyBudget_matrix);
% TransferEfficiency                               = ECOTRAN.TransferEfficiency; % gets redefined manually below


% step 4c: find detritus, nutrients, BA & EM ------------------------------
%          by row address in EnergyBudget_matrix
looky_NUTRIENTS                                  = find(floor(GroupType) == ECOTRAN.GroupTypeDef_ANYNitroNutr);
looky_NO3                                        = find(GroupType        == ECOTRAN.GroupTypeDef_NO3);
looky_plgcNH4                                    = find(GroupType        == ECOTRAN.GroupTypeDef_plgcNH4);
looky_bnthNH4                                    = find(GroupType        == ECOTRAN.GroupTypeDef_bnthNH4);
looky_PrimaryProducer                            = find(floor(GroupType) == ECOTRAN.GroupTypeDef_ANYPrimaryProd);
looky_Macroalgae                                 = find(GroupType        == ECOTRAN.GroupTypeDef_Macrophytes);
looky_Phytoplankton                              = looky_PrimaryProducer(~ismember(looky_PrimaryProducer, looky_Macroalgae));
looky_DETRITUS                                   = find(floor(GroupType) == ECOTRAN.GroupTypeDef_ANYDetritus);
looky_terminalPlgcDetr                           = find(GroupType        == ECOTRAN.GroupTypeDef_terminalPlgcDetr);
looky_terminalBnthDetr                           = find(GroupType        == ECOTRAN.GroupTypeDef_terminalBnthDetr);
looky_ULTIMATEdetritus                           = find(GroupType        == ECOTRAN.GroupTypeDef_ULTIMATEdetritus);
looky_eggs                                       = find(GroupType        == ECOTRAN.GroupTypeDef_eggs);
looky_ANYConsumer                                = find(floor(GroupType) == ECOTRAN.GroupTypeDef_ANYConsumer);
looky_fishery                                    = find(GroupType        == ECOTRAN.GroupTypeDef_fishery);
looky_nonNO3                                     = 1:E2E_clms;
looky_nonNO3(looky_NO3)                          = [];
% looky_nonNO3(looky_NUTRIENTS)                    = [];                        % SSS add NH4 if NH4 is also a physically imported driver
num_Nutrients                                    = length(looky_NUTRIENTS);
num_NH4                                          = length([looky_plgcNH4; looky_bnthNH4]);
num_PrimaryProducers                             = length(looky_PrimaryProducer);
num_Macroalgae                                   = length(looky_Macroalgae);
num_Phytoplankton                                = length(looky_Phytoplankton);
num_eggs                                         = length(looky_eggs);
num_detritus                                     = length(looky_DETRITUS);


% step 4d: the ODE will need these ----------------------------------------
ODEinput.looky_NUTRIENTS                         = looky_NUTRIENTS;
ODEinput.looky_NO3                               = looky_NO3;
ODEinput.looky_plgcNH4                           = looky_plgcNH4;
ODEinput.looky_bnthNH4                           = looky_bnthNH4;
ODEinput.looky_PrimaryProducer                   = looky_PrimaryProducer;
ODEinput.looky_Macroalgae                        = looky_Macroalgae;
ODEinput.looky_Phytoplankton                     = looky_Phytoplankton;
ODEinput.looky_terminalPlgcDetr                  = looky_terminalPlgcDetr;
ODEinput.looky_terminalBnthDetr                  = looky_terminalBnthDetr;
ODEinput.looky_ULTIMATEdetritus                  = looky_ULTIMATEdetritus;
ODEinput.looky_DETRITUS                          = looky_DETRITUS;
ODEinput.looky_eggs                              = looky_eggs;
ODEinput.looky_ANYConsumer                       = looky_ANYConsumer;
ODEinput.looky_fishery                           = looky_fishery;
ODEinput.looky_nonNO3                            = looky_nonNO3;
ODEinput.num_PrimaryProducers                    = num_PrimaryProducers;
ODEinput.num_Macroalgae                          = num_Macroalgae;
ODEinput.num_Phytoplankton                       = num_Phytoplankton;
ODEinput.num_predators                           = length([looky_ANYConsumer; looky_fishery]);
ODEinput.num_eggs                                = length(looky_eggs);
ODEinput.num_NH4                                 = num_NH4;
ODEinput.num_bnthNH4                             = length(looky_bnthNH4);
ODEinput.E2E_rows                                = num_E2Egroups;
ODEinput.E2E_clms                                = num_E2Egroups;


% step 4e: matrix addresses of ECOTRAN generic model groups ---------------
%          NOTE: these must be entered manually for each new model, for easier plotting
NO3_rowclm                      = 1;
pelagicNH4_rowclm               = 2;
benthicNH4_rowclm               = 3;
SmlPhyto_rowclm                 = 4;
LargePhyto_rowclm               = 5;
macroalgae_RC                   = 6;
microzooplankton_RC             = 7;
mesozooplankton_RC              = 8;
macrozooplankton_RC             = 9;
euphausiids_RC                  = 10;
gelatinousZooplankton_RC        = 11;
squid_RC                        = 12;
juvenileFish_RC                 = 13;
planktivorousFish_RC            = 14;
piscivorousFish_RC              = 15;
benthivorousFish_RC             = 16;
demersalShrimp_RC               = 17;
meiobenthos_RC                  = 18;
depositFeedingBenthos_RC        = 19;
suspFeedingBenthos_RC           = 20;
carnivorousBenthos_RC           = 21;
seabirds_RC                     = 22;
baleenWhales_RC                 = 23;
pinnipeds_RC                    = 24;
odontocetes_RC                  = 25;
invertebrateEggs_RC             = 26;
fishEggs_RC                     = 27;
fisheries_RC                    = 28; % <<--note that fisheries come before terminal detritu
pelagicDetritus_RC              = 29;
benthicDetritus_RC              = 30;
ULTIMATEdetritus_RC             = 31;





% *************************************************************************
% STEP 5: define TransferEfficiency terms----------------------------------
%         SET MANUALLY: TransferEfficiency = 1 for all groups because we are
%                       working with the consumption budget matrix that tracks the fate of ALL consumption (not just predation)
%                       system losses (groups where TransferEfficiency < 1 include benthic detritus, fishery, (others?)
%          NOTE: terminal benthic detritus column in EnergyBudget_matrix sums to 1 and has NO OtherMortality, 
%                TE is the only means of removing terminal benthic detritus from system
TransferEfficiency                            = ones(num_webMonteCarlo, num_E2Egroups); % re-initialize as rows of horizontal vector of ones

% TransferEfficiency(:, [pelagicNH4_rowclm])   = 0.25;    % SSS default TE for pelagic detritus = 0.25 in the static model analysis

TransferEfficiency(:, [pelagicNH4_rowclm])   = 0.72;    % SSS for NorSeaweb basin; f-ratio = 0.15; (reflective boundary conditions)





% *************************************************************************
% STEP 6: prepare physical parameters--------------------------------------
% step 6a: input time-frame info ------------------------------------------
datestart                       = datenum('01-Jan-2001'); % SSS --> enter starting date
dateend                         = datenum('31-Dec-2020'); % SSS --> enter ending date (default for dynamic runs ('31-Dec-2020'))
dt                              = 1; % t-step (d) <<<---ALWAYS set to 1
datestart_OrdinalDate           = f_OrdinalDate(datestart);
dateend_OrdinalDate             = f_OrdinalDate(dateend);
min_t                           = datestart_OrdinalDate;
max_t                           = (dateend - datestart) + datestart_OrdinalDate;
t_grid                          = linspace(min_t, max_t, ((dateend - datestart + 1)/dt))'; % (vertical vector)
num_t                           = length(t_grid); % length of t_grid; (scaler)
PHYSICSinput.datestart          = datestart;
PHYSICSinput.dateend            = dateend;
PHYSICSinput.dt                 = dt;
PHYSICSinput.t_grid             = t_grid;


% step 6b: prepare advection & mixing time-series for each model box ------
[ECOTRANphysics]                = f_ECOTRANphysics_basin_08022018(PHYSICSinput);    % SSS


% step 6c: unpack & process physics variables -----------------------------
AdvectionMatrix                  = ECOTRANphysics.AdvectionMatrix;                  % volume transported per day;        (m3/d); (3D matrix: time X source boxes X destination boxes)
RiverFluxMatrix                  = ECOTRANphysics.RiverFluxMatrix;                  % volume transported per day;        (m3/d); (3D matrix: time X source boxes X destination boxes)
VerticalMixMatrix                = ECOTRANphysics.VerticalMixMatrix;                % volume mixed vertically per day;   (m3/d); (3D matrix: time X source boxes X destination boxes)
HorizontalMixMatrix              = ECOTRANphysics.HorizontalMixMatrix;              % volume mixed horizontally per day; (m3/d); (3D matrix: time X source boxes X destination boxes)
HorizontalMix_OffshoreSurface    = ECOTRANphysics.HorizontalMix_OffshoreSurface;    % mixing rate across oceanic boundary = volume mixed per day; (m3/d); (vertical vector: time X 1)
HorizontalMix_OffshoreSubSurface = ECOTRANphysics.HorizontalMix_OffshoreSubSurface; % mixing rate across oceanic boundary = volume mixed per day; (m3/d); (vertical vector: time X 1)
num_boxes                        = ECOTRANphysics.num_boxes;
looky_SubSurfaceBoxes            = ECOTRANphysics.looky_SubSurfaceBoxes;
looky_SurfaceBoxes               = ECOTRANphysics.looky_SurfaceBoxes;
looky_OffshoreSurfaceBox         = ECOTRANphysics.looky_OffshoreSurfaceBox;
looky_OffshoreSubSurfaceBox      = ECOTRANphysics.looky_OffshoreSubSurfaceBox;
looky_RiverFluxBox               = ECOTRANphysics.looky_RiverFluxBox;               % River input from alongshore; Box 2 in CGoA model;
num_SubSurfaceBoxes              = length(looky_SubSurfaceBoxes);
dat_NO3                          = ECOTRANphysics.dat_NO3;                          % monthly means NO3 + NO2 in phytoplankton WWT equivalents; (mmole N / m3); (2D matrix: month X box; I, II, III, IV, V)
NO3_doy                          = ECOTRANphysics.NO3_doy;                          % daily NO3 + NO2 interpolated from monthly means; (mmole N/m3); (2D matrix: num_t X box; I, II, III, IV, V)
BoxLength                        = ECOTRANphysics.BoxLength;                        % (m); (2D matrix: time X num_boxes)
BoxHeight                        = ECOTRANphysics.BoxHeight;                        % I, II, III, IV, V; (m); (2D matrix: time X num_boxes)
BoxWidth                         = ECOTRANphysics.BoxWidth;                         % I, II, III, IV, V; (m); (2D matrix: time X num_boxes)
BoxVolume                        = ECOTRANphysics.BoxVolume;                        % I, II, III, IV, V; (m3); (2D matrix: time X num_boxes)
MLD                              = ECOTRANphysics.MLD;                              % mixed-layer depth; (m); (vertical vector: days X 1)
EuphoticDepth                    = repmat(MLD, [1 num_boxes]);                      % FFF (eventually move to f_physics code); depth of euphotic zone, used when converting the vertically-integrated EwE primary producer biomass to biomass/volume; depth % I, II, III, IV, V; (m3); (2D matrix: time X num_boxes)
Io                               = ECOTRANphysics.Io;                               % time-series of surface PAR light intensity; daily integrated solar raditation at ocean surface averaged across 24 hours; (W m^-2 h^-1); (vertical vector: days X 1)
Kw                               = ECOTRANphysics.Kw;                               % Light attenuation_seawater; (scaler)
Kp                               = ECOTRANphysics.Kp;                               % Light attenuation_phytoplankton (Newberger et al., 2003); (m2/mmol N)
SinkLink_surface                 = ECOTRANphysics.SinkLink_surface;                 % define sinking connections from surface to sub-surface boxes; (unitless); (2D matrix: destination boxes X source boxes)
SinkLink_surface                 = reshape(SinkLink_surface, [num_boxes, 1, num_boxes]);    % (3D matrix: destination boxes X 1 X source boxes)
SinkLink_surface                 = repmat(SinkLink_surface, [1, num_E2Egroups, 1]);         % (unitless); (3D matrix: destination boxes X num_E2Egroups X source boxes)
SinkLink_benthos                 = ECOTRANphysics.SinkLink_benthos;                         % define sinking connections from sub-surface boxes to benthic detritus; (unitless); (2D matrix: destination boxes X source boxes)
SinkLink_benthos                 = reshape(SinkLink_benthos, [num_boxes, 1, num_boxes]);    % (3D matrix: destination boxes X 1 X source boxes)
SinkLink_benthos                 = repmat(SinkLink_benthos, [1, num_E2Egroups, 1]);         % (unitless); (3D matrix: destination boxes X num_E2Egroups X source boxes)
WWT_to_C                         = ECOTRANphysics.WWT_to_C;
atomic_mass_C                    = ECOTRANphysics.atomic_mass_C;
C_to_N_phytoplankton             = ECOTRANphysics.C_to_N_phytoplankton;


% step 6d: distinguish between surface & sub-surface EnergyBudget_matrix --
EnergyBudget_BoxType                                                                                                          = ones(num_E2Egroups, num_E2Egroups, num_boxes); % (3D matrix: num_E2Egroups, num_E2Egroups, num_boxes)
EnergyBudget_BoxType(:, :, looky_SubSurfaceBoxes)                                                                             = 0; % by default, allow no trophic interactions in sub-surface boxes; (3D matrix: num_E2Egroups, num_E2Egroups, num_boxes)
EnergyBudget_BoxType(looky_NO3, [looky_plgcNH4; looky_bnthNH4], looky_SubSurfaceBoxes)                                        = 1; % allow oxidation of NH4 to NO3; (3D matrix: num_E2Egroups, num_E2Egroups, num_boxes)
% EnergyBudget_BoxType([looky_plgcNH4; looky_bnthNH4], [looky_terminalPlgcDetr; looky_terminalBnthDetr], looky_SubSurfaceBoxes) = 1; % allow implicit bacterial metabolism of detritus; (3D matrix: num_E2Egroups, num_E2Egroups, num_boxes)
EnergyBudget_BoxType([looky_plgcNH4; looky_bnthNH4], looky_DETRITUS, looky_SubSurfaceBoxes)                                   = 1; % allow implicit bacterial metabolism of detritus; (3D matrix: num_E2Egroups, num_E2Egroups, num_boxes)
EnergyBudget_BoxType([looky_terminalPlgcDetr; looky_terminalBnthDetr], looky_PrimaryProducer, looky_SubSurfaceBoxes)          = 1; % allow flow of primary producers to detritus; (3D matrix: num_E2Egroups, num_E2Egroups, num_boxes)
EnergyBudget_BoxType(looky_DETRITUS, looky_DETRITUS, looky_SubSurfaceBoxes)                                                   = 1; % allow flow between detritus pools (including flow of terminal pelagic detritus to terminal benthic detritus); (3D matrix: num_E2Egroups, num_E2Egroups, num_boxes)

EnergyBudget_BoxType(:, :, [1 4 5])                                                                                           = EnergyBudget_BoxType(:, :, [1 4 5]) * 0; % SSS turn off trophics in all boxes but 2 & 3 when running in the basin physical model


% step 6e: define production loss fractions -------------------------------
%          NOTE: this used for initial conditions only (for dynamic models)
%          NOTE: the ODE accounts for physical removal (or addition) at each tie-step; while the static model accounts for physical loss as a reduction in Transfer Efficiency
%                    this is the way it was handled in John's original code outline and in the pubs
LX                       = 0;                                               % NOTE: set to zeros for initial conditions; set to 0 to ignore physical losses; 
% LX                       = ones(num_t, num_E2Egroups);                      % NOTE: set to 1 for the default relative upwelling index (1 is used for the average yearly relative upwelling index)
ProductionLossScaler     = [zeros(1, num_Nutrients) ProductionLossScaler];  % append nutrients at start; (horizontal vector)
ProductionLossScaler     = repmat(ProductionLossScaler, [num_t, 1]);        % (2D matrix: time X groups)
PhysicalLossFraction     = ProductionLossScaler .* LX;                      % (2D matrix: time X groups)


% step 6f: prepare RetentionScaler ----------------------------------------
RetentionScaler          = [zeros(1, num_Nutrients) RetentionScaler];       % append nutrients at start;        (horizontal vector)
RetentionScaler_repmat   = repmat(RetentionScaler, [1, 1, num_boxes]);      % replicate for each spatial box;   (3D matrix: 1 X num_E2Egroups X num_boxes)


% step 6g: sinking rate of each group (m/d) -------------------------------
%          NOTE: sinking is treated like a physical term (i.e., not incorporated into EnergyBudget_matrix)
%          NOTE: apply this factor whether or not using Michaelis-Menten for primary producers
% MichaelisMenten_w                       = [0.6 1.0];                                    % sinking rate; (m/d); [Sm Phytoplankton, Lg Phytoplankton]
SinkRate                                = zeros(1, num_E2Egroups, num_boxes);           % SSS; sinking rate; (m/d); (3D matrix: 1 X num_E2Egroups X num_boxes)
SinkRate(1, SmlPhyto_rowclm, :)         = 0.6;                                          % SSS; sinking rate; (m/d); (3D matrix: 1 X num_E2Egroups X num_boxes)
SinkRate(1, LargePhyto_rowclm, :)       = 1;                                            % SSS; sinking rate; (m/d); (3D matrix: 1 X num_E2Egroups X num_boxes)
% SinkRate(1, SmlPhyto_rowclm, :)         = 0.8;                                          % SSS; change for NorSea web; sinking rate; (m/d); (3D matrix: 1 X num_E2Egroups X num_boxes)
% SinkRate(1, LargePhyto_rowclm, :)       = 0.8;                                          % SSS; change for NorSea web; sinking rate; (m/d); (3D matrix: 1 X num_E2Egroups X num_boxes)
% SinkRate(1, looky_PrimaryProducer, :)   = repmat(MichaelisMenten_w, [1, 1, num_boxes]); % sinking rate; (m/d); (3D matrix: 1 X num_E2Egroups X num_boxes)
SinkRate                                = repmat(SinkRate, [num_t, 1, 1]);              % sinking rate; (m/d); (3D matrix: num_t X num_E2Egroups X num_boxes)


% step 6h: pack physics values for ODE into ODEinput ----------------------
ODEinput.AdvectionMatrix                    = AdvectionMatrix;                  % volume transported per day;        (m3/d); (3D matrix: time X source boxes X destination boxes)
ODEinput.RiverFluxMatrix                    = RiverFluxMatrix;                  % volume transported per day;        (m3/d); (3D matrix: time X source boxes X destination boxes)
ODEinput.VerticalMixMatrix                  = VerticalMixMatrix;                % volume mixed vertically per day;   (m3/d); (3D matrix: time X source boxes X destination boxes)
ODEinput.HorizontalMixMatrix                = HorizontalMixMatrix;              % volume mixed horizontally per day; (m3/d); (3D matrix: time X source boxes X destination boxes)
ODEinput.HorizontalMix_OffshoreSurface      = HorizontalMix_OffshoreSurface;    % mixing rate across oceanic boundary = volume mixed per day; (m3/d); (vertical vector: time X 1)
ODEinput.HorizontalMix_OffshoreSubSurface   = HorizontalMix_OffshoreSubSurface; % mixing rate across oceanic boundary = volume mixed per day; (m3/d); (vertical vector: time X 1)
ODEinput.SinkLink_surface                   = SinkLink_surface;                 % define sinking connections from surface to sub-surface boxes;          (unitless); (3D matrix: destination boxes X num_E2Egroups X source boxes)
ODEinput.SinkLink_benthos                   = SinkLink_benthos;                 % define sinking connections from sub-surface boxes to benthic detritus; (unitless); (3D matrix: destination boxes X num_E2Egroups X source boxes)
ODEinput.num_boxes                          = num_boxes;
ODEinput.looky_SurfaceBoxes                 = looky_SurfaceBoxes;
ODEinput.looky_SubSurfaceBoxes              = looky_SubSurfaceBoxes;
ODEinput.looky_OffshoreSurfaceBox           = looky_OffshoreSurfaceBox;
ODEinput.looky_OffshoreSubSurfaceBox        = looky_OffshoreSubSurfaceBox;
ODEinput.BoxLength                          = BoxLength;                        % (m);  (2D matrix: time X num_boxes)
ODEinput.BoxHeight                          = BoxHeight;                        % (m);  (2D matrix: time X num_boxes)
ODEinput.BoxWidth                           = BoxWidth;                         % (m);  (2D matrix: time X num_boxes)
ODEinput.BoxVolume                          = BoxVolume;                        % (m3); (2D matrix: time X num_boxes)
ODEinput.spatial_BiomassScalers             = [1 1 0 1 0];                      % scalers for estimating initial (or mean) primary producer biomasses across model domain; NOTE: these values are assumed; NOTE: x2 in Box I used to compensate for 30m depth relative to 15 m depths in Boxes II & IV; FFF apply NPZD scalers here
ODEinput.t_grid                             = t_grid;    
ODEinput.MLD                                = MLD;                              % (vertical vector: length = time)
ODEinput.Io                                 = Io;
ODEinput.Kw                                 = Kw;
ODEinput.Kp                                 = Kp;
ODEinput.RetentionScaler                    = RetentionScaler_repmat;
ODEinput.EnergyBudget_BoxType               = EnergyBudget_BoxType;             % distinguish between surface & sub-surface EnergyBudget_matrix; (3D matrix: num_E2Egroups, num_E2Egroups, num_boxes)


% step 6i: re-shape BoxVolume & BoxHeight (for later calcs) ---------------
BoxVolume_temp                              = reshape(BoxVolume, [num_t, 1, num_boxes]);        % (m3); (3D matrix: num_t X 1      X num_boxes)
BoxVolume_repmat                            = repmat(BoxVolume_temp, [1, num_E2Egroups, 1]);    % (m3); (3D matrix: num_t X groups X num_boxes)
BoxHeight_temp                              = reshape(BoxHeight, [num_t, 1, num_boxes]);        % (m);  (3D matrix: num_t X 1      X num_boxes)
BoxHeight_repmat                            = repmat(BoxHeight_temp, [1, num_E2Egroups, 1]);    % (m);  (3D matrix: num_t X groups X num_boxes)

clear BoxVolume_temp BoxHeight_temp





% *************************************************************************
% STEP 7: prepare Production_input driver time-series----------------------
%         NOTE: This is the external input from offshore and/or alongshore 
%               and/or river that enters the model domain via advection and 
%               mixing. Under the reflective boundary assumption, only specified 
%               groups (NO3) are advected into the model domain, and the code eliminates 
%               advection of non-NO3 groups (or of empty water) into the domain.
%               The reflective boundary assumption is that biomass of non-NO3 
%               groups is the same on either side of model domain outer
%               boundaries.
%
% step 7a: define driver groups and time-periods for initial and mean conditions
driver_rowclm                                 = [NO3_rowclm];               % row address(es) of driver group(s)
% zero out energy flow to drivers in EnergyBudget_matrix (set ROWS to zero)
EnergyBudget_matrix(driver_rowclm, :, :)      = 0;                          % NOTE: this de-activates any NH4 oxidation to NO3 for dynamic runs; (3D matrix: num_E2Egroups X num_nutrients X num_webMonteCarlo)
EnergyBudget_matrix(:, looky_NUTRIENTS, :)    = EnergyBudget_matrix(:, looky_NUTRIENTS, :) ./ repmat(sum(EnergyBudget_matrix(:, looky_NUTRIENTS, :)), [num_E2Egroups 1 1]); % re-normalize nutrient distribution to remove NH4 oxidation to NO3


% step 7b: daily and seasonal mean NO3 concentrations (mmoles N/m3) -------
%          NOTE: for daily NO3 concentrations @ t, use NO3_doy
t_initial                                  = 1;                             % t for initial conditions (Jan 1)
t_mean                                     = 183;                           % t for mean conditions (mid-year)
meanNO3_spring                             = mean(dat_NO3(3:5, :), 1);      % offshore NO3 density in summer @ surface; (mmole N/m3); (horizontal vector: 1 X num_boxes)
meanNO3_summer                             = mean(dat_NO3(6:9, :), 1);      % offshore NO3 density in summer @ surface; (mmole N/m3); (horizontal vector: 1 X num_boxes)
meanNO3_winter                             = mean(dat_NO3([12 1 2], :), 1); % offshore NO3 density in summer @ surface; (mmole N/m3); (horizontal vector: 1 X num_boxes)
meanNO3_annual                             = mean(dat_NO3, 1);              % offshore NO3 density in summer @ surface; (mmole N/m3); (horizontal vector: 1 X num_boxes)
initialNO3                                 = meanNO3_annual;                %                                           (mmole N/m3); (horizontal vector: 1 X num_boxes)
meanNO3                                    = meanNO3_annual;                %                                           (mmole N/m3); (horizontal vector: 1 X num_boxes)
initialNH4                                 = [0 0 0 0 0];                   %                                           (mmole N/m3); (horizontal vector: 1 X num_boxes)
meanNH4                                    = [0 0 0 0 0];                   %                                           (mmole N/m3); (horizontal vector: 1 X num_boxes)
NO3_timeseries                             = NO3_doy;                       %                                           (mmole N/m3); (2D matrix: num_t X num_boxes)


% step 7c: load or create external driver time-series ---------------------
%          calculate daily advection rates of NO3 INTO the model domain
%          could use EITHER seasonal mean NO3 concentrations here OR daily value in NO3_doy
%          Production_input    (mmole N/m3/d)  (3D matrix: time X groups X num_boxes)
Advection_DestinationSum                                        = sum(AdvectionMatrix, 2) * (-1);                              % advected volume;                                               (m3/d); (3D matrix: time X 1 X DestinationBoxes)
RiverFlux_DestinationSum                                        = sum(RiverFluxMatrix, 2);                                     % NOTE: sign lack of change for basin case; advected volume;      (m3/d); (3D matrix: time X 1 X DestinationBoxes)
Advection_DestinationSum                                        = Advection_DestinationSum + RiverFlux_DestinationSum;         % NOTE: new line for basin case; river flux into Box 1 is now included in Advection_DestinationSum
%   NOTE: all advection terms except those from external inputs (i.e. ocean or river) cancel out; 
%   NOTE: *(-1) because direction is onshore but need positive input of driver(s);
Advection_OffshoreSurface                                       = Advection_DestinationSum(:, 1, looky_OffshoreSurfaceBox);    % advected volume into offshore surface box;                      (m3/d); (vertical vector: time X 1)
Advection_OffshoreSubSurface                                    = Advection_DestinationSum(:, 1, looky_OffshoreSubSurfaceBox); % advected volume into offshore sub-surface box;                  (m3/d); (vertical vector: time X 1)
Advection_RiverSurface                                          = RiverFlux_DestinationSum(:, 1, looky_RiverFluxBox) * (-1);   % NOTE: sign change for basin case; advected volume from alongshore river input into surface Box 1; (m3/d); (vertical vector: time X 1)

Production_input                                                = zeros(num_t, num_E2Egroups, num_boxes);                                         % initialize input production;                      (3D matrix: time X groups X num_boxes)
Production_input(:, driver_rowclm, looky_OffshoreSurfaceBox)    = Advection_OffshoreSurface    .* NO3_timeseries(:, looky_OffshoreSurfaceBox);    % total biomass advected in/out of box (mmole N/d); (3D matrix: time X groups X num_boxes)
Production_input(:, driver_rowclm, looky_OffshoreSubSurfaceBox) = Advection_OffshoreSubSurface .* NO3_timeseries(:, looky_OffshoreSubSurfaceBox); % total biomass advected in/out of box (mmole N/d); (3D matrix: time X groups X num_boxes)
Production_input(:, driver_rowclm, looky_RiverFluxBox)          = Advection_RiverSurface       .* NO3_timeseries(:, looky_RiverFluxBox);          % total biomass advected in/out of box (mmole N/d); (3D matrix: time X groups X num_boxes)
Production_input                                                = Production_input ./ BoxVolume_repmat;                                           % (mmole N/m3/d); (3D matrix: time X groups X num_boxes); defines NO3 input rate into model domain, this only has input to offshore and river input boxes, other boxes and groups = 0





% *************************************************************************
% STEP 8: prepare non-predation BioenergeticBudget terms-------------------
% step 8a: define weight-specific growth & consumption rates --------------
SpecificGrowthRate                              = EwE_PB / 365;                                                     % define growth rates; (1/d); (vertical vector: num_E2Egroups X 1)
SpecificGrowthRate(looky_NUTRIENTS)             = 1;                                                                % NUTRIENTS converted from NaN to 1; (1/d); (vertical vector: num_E2Egroups X 1)
SpecificGrowthRate                              = SpecificGrowthRate';                                              % (1/d); (horizontal vector: 1 X num_E2Egroups)
SpecificGrowthRate                              = repmat(SpecificGrowthRate, [num_t, 1, num_webMonteCarlo]);        % (1/d); (3D matrix: num_t X num_E2Egroups X num_webMonteCarlo)
SpecificConsumptionRate                         = EwE_QB / 365;                                                     % define consumption rates; (1/d); (vertical vector: num_E2Egroups X 1)
SpecificConsumptionRate(looky_NUTRIENTS)        = 1;                                                                % NUTRIENTS converted from NaN to 1;   (1/d); (vertical vector: num_E2Egroups X 1)
SpecificConsumptionRate                         = SpecificConsumptionRate';                                         % (1/d); (horizontal vector: 1 X num_E2Egroups)
SpecificConsumptionRate                         = repmat(SpecificConsumptionRate, [num_t, 1, num_webMonteCarlo]);   % (1/d); (3D matrix: num_t X num_E2Egroups X num_webMonteCarlo)


% % step 8b: (FFF in future, allow for seasonal change time-series) ---------
% [SpecificGrowthRate_PrimaryProducers, Biomass_PrimaryProducers] = f_SeasonalPB_PrimaryProducers(ECOTRANphysics, ODEinput, EwEResult); % (1/d); (3D matrix: num_t X num_PrimaryProducers X num_boxes)
% SpecificGrowthRate(:, looky_PrimaryProducer)      = SpecificGrowthRate_PrimaryProducers(:, :, 1); % plug in new primary producer timeseries; use Box 1 as the full domain definition
% SpecificConsumptionRate(:, looky_PrimaryProducer) = SpecificGrowthRate_PrimaryProducers(:, :, 1); % plug in new primary producer timeseries; use Box 1 as the full domain definition


% step 8c: initialize terms based on steady-state ECOTRAN solutions -------
%          (rows = time, clms = ECOTRAN groups, layers = MonteCarlo models)
%          NOTE: FFF at this point in the code, we can read in time-series changes for each of these terms
%                this would allow for seasonal reproduction differences (BioenergeticBudget_eggs), & 
%                seasonal migration changes (BioenergeticBudget_EM)
BioenergeticBudget_feces          = repmat(ConsumptionBudget_MonteCarlo(1, :, :), [num_t, 1, 1]); % (3D matrix: num_t X num_E2Egroups X num_webMonteCarlo)
BioenergeticBudget_metabolism     = repmat(ConsumptionBudget_MonteCarlo(2, :, :), [num_t, 1, 1]); % (3D matrix: num_t X num_E2Egroups X num_webMonteCarlo)
BioenergeticBudget_eggs           = repmat(ConsumptionBudget_MonteCarlo(3, :, :), [num_t, 1, 1]); % (3D matrix: num_t X num_E2Egroups X num_webMonteCarlo)
BioenergeticBudget_predation      = repmat(ConsumptionBudget_MonteCarlo(4, :, :), [num_t, 1, 1]); % (3D matrix: num_t X num_E2Egroups X num_webMonteCarlo)
BioenergeticBudget_OtherMortality = repmat(ConsumptionBudget_MonteCarlo(5, :, :), [num_t, 1, 1]); % (3D matrix: num_t X num_E2Egroups X num_webMonteCarlo)
BioenergeticBudget_BA             = repmat(ConsumptionBudget_MonteCarlo(6, :, :), [num_t, 1, 1]); % (3D matrix: num_t X num_E2Egroups X num_webMonteCarlo)
BioenergeticBudget_EM             = repmat(ConsumptionBudget_MonteCarlo(7, :, :), [num_t, 1, 1]); % (3D matrix: num_t X num_E2Egroups X num_webMonteCarlo)


% % step 8d: set senescence term for terminal benthic detritus to 0 ---------
% %          add senescence term to predation term so that total bioenergetic
% %          budget for terminal benthic detritus = 1 (i.e., re-normalize clm)
% %          senescence removal for terminal benthic detritus is accounted
% %          for via TransferEfficiency
% %
% %          NOTE: SSS deactivate this sub-step when the ULTIMATE detritus group is added
% %
% BioenergeticBudget_predation(:, looky_terminalBnthDetr, :)      = BioenergeticBudget_predation(:, looky_terminalBnthDetr, :) + BioenergeticBudget_OtherMortality(:, looky_terminalBnthDetr, :);
% BioenergeticBudget_OtherMortality(:, looky_terminalBnthDetr, :) = 0;      % (3D matrix: num_t X num_E2Egroups X num_webMonteCarlo)


% % % % step 8e: set senescence term(s) for primary producers to NPZD model values (FFF move this for aesthetic resons??)
% % % %          NOTE: activate this setp if using Michaelis-Menten definition of primary producer senescence
% % % %          NOTE: this coding adpated especially for models which also have a macroalgae primary producer
% % % eta_SmPhytoplankton = 0;                                                            % phytoplankton non-grazing mortality; (1/d); Need an entry for each primary producer; (1 X num_PrimaryProducers); (FFF in future; move all NPZD parameters to VisualBasic entry)
% % % eta_LgPhytoplankton = 0;                                                            % phytoplankton non-grazing mortality; (1/d); Need an entry for each primary producer; (1 X num_PrimaryProducers); (FFF in future; move all NPZD parameters to VisualBasic entry)
% % % eta_SmPhytoplankton = repmat(eta_SmPhytoplankton, [num_t, 1, num_webMonteCarlo]);	% phytoplankton non-grazing mortality; (1/d); (3D matrix: num_t X 1 X num_webMonteCarlo)
% % % eta_LgPhytoplankton = repmat(eta_LgPhytoplankton, [num_t, 1, num_webMonteCarlo]);   % phytoplankton non-grazing mortality; (1/d); (3D matrix: num_t X 1 X num_webMonteCarlo)
% % % %          NOTE: in NPZD: non-grazing mortality rate (t/km2/d) = biomass (t/km2) * eta (1/d)
% % % %                in ECOTRAN: senescence rate (t/km2/d)         = EnergyBudget (unitless) * ProductionRatesP (t/km2/d)
% % % %                Substitution into ECOTRAN EnergyBudget_matrix is therefore = eta (1/d) * 1/PB (d)
% % % BioenergeticBudget_inner_OtherMortality(:, SmlPhyto_rowclm, :)   = eta_SmPhytoplankton .* (1./SpecificGrowthRate(:, SmlPhyto_rowclm, :));   % QQQ 5/12/2014 recheck logic on units here; also note: SpecificGrowthRate = SpecificConsumptionRate for primary producers
% % % BioenergeticBudget_inner_OtherMortality(:, LargePhyto_rowclm, :) = eta_LgPhytoplankton .* (1./SpecificGrowthRate(:, LargePhyto_rowclm, :)); % QQQ 5/12/2014 recheck logic on units here; also note: SpecificGrowthRate = SpecificConsumptionRate for primary producers
% % % BioenergeticBudget_mid_OtherMortality(:, SmlPhyto_rowclm, :)     = eta_SmPhytoplankton .* (1./SpecificGrowthRate(:, SmlPhyto_rowclm, :));   % QQQ 5/12/2014 recheck logic on units here; also note: SpecificGrowthRate = SpecificConsumptionRate for primary producers
% % % BioenergeticBudget_mid_OtherMortality(:, LargePhyto_rowclm, :)   = eta_LgPhytoplankton .* (1./SpecificGrowthRate(:, LargePhyto_rowclm, :)); % QQQ 5/12/2014 recheck logic on units here; also note: SpecificGrowthRate = SpecificConsumptionRate for primary producers
% % % BioenergeticBudget_outer_OtherMortality(:, SmlPhyto_rowclm, :)   = eta_SmPhytoplankton .* (1./SpecificGrowthRate(:, SmlPhyto_rowclm, :));   % QQQ 5/12/2014 recheck logic on units here; also note: SpecificGrowthRate = SpecificConsumptionRate for primary producers
% % % BioenergeticBudget_outer_OtherMortality(:, LargePhyto_rowclm, :) = eta_LgPhytoplankton .* (1./SpecificGrowthRate(:, LargePhyto_rowclm, :)); % QQQ 5/12/2014 recheck logic on units here; also note: SpecificGrowthRate = SpecificConsumptionRate for primary producers
% % % % QQQ need to make sure this also fixed in EnergyBudget matrix, in ODE???


% step 8f: filter out any negative trace values in BioenergeticBudget_OtherMortality
BioenergeticBudget_OtherMortality(BioenergeticBudget_OtherMortality < 0) = 0; % I find extremely small trace negative values for fishery clms





% % % % *************************************************************************
% % % % STEP 9: define functional predator-prey relations------------------------
% % % %         NOTE: STEP DEACTIVATED - FUNCTIONAL RESPONSE DEFINED LATER IN MONTE CARLO LOOP
% % % % step 9a: select a "linear" or "ECOSIM" response -------------------------
% % % %          NOTE: to change one half-sat constant for individual groups, change EL([Grp_rowclm])
% % % %                EL = 0 is "linear"
% % % %                EL = 1 is "non-linear" ECOSIM default
% % % EL                                     = [zeros(1, num_Nutrients) FunctionalResponseParams(1, :)]; % append nutrients (to start); choose only the first of the four potential FunctionalResponseParams; (horizontal vector: 1 X num_E2Egroups)
% % % EL                                     = EL';                                   % transpose to vertical vector; (vertical vector: num_E2Egroups X 1)
% % % EL([looky_NUTRIENTS; looky_DETRITUS])  = 0;                                     % set so that flow to nutrients & detritus is linear (should already be done, but just in case); (vertical vector: num_E2Egroups X 1)
% % % EL_repmat                              = repmat(EL, [1, num_E2Egroups]);      	% replicate EL across clms; (2D matrix: CONSUMERS X groups)
% % % % NOTE: EL is a function of the CONSUMER (not the producer) and needs to be aligned with the consumer ROWS in ECOTRAN (not producer clms)
% % % % NOTE: to change one half-sat constant for individual groups, change EL([Grp_rowclm])
% % % EL_repmat                              = repmat(EL_repmat, [1, 1, num_boxes]);  % replicate again for each spatial box; (CONSUMERS X groups X num_boxes)
% % % EL_repmat(:, :, looky_SubSurfaceBoxes) = 0;                                     % functional response terms in sub-surface boxes are all linear
% % % ODEinput.FunctionalResponseParams      = EL_repmat;                         	% pack to send to ODE; (3D matrix: consumers X producers X num_boxes)
% % % % CV_FunctionalResponse                  = ones(num_E2Egroups, 1) * 5;
% % % % FunctionalResponseParams               = f_FunctionalResponse_MonteCarlo_09122016(ECOTRAN, ODEinput, CV_FunctionalResponse);
% % % % ODEinput.FunctionalResponseParams      = FunctionalResponseParams;            % pack to send to ODE; (3D matrix: consumers X producers X num_boxes)





% *************************************************************************
% STEP 10: define Michaelis-Menten functional predator-prey relations------
%         NOTE: for primary producers
% step 10a: initialize MichaelisMenten parameter matrices -----------------
MichaelisMenten_Vmax     = zeros(num_E2Egroups, 1, num_boxes); % Vmax  = maximum nutrient uptake rate;          (1/d);        (3D matrix: num_E2Egroups X 1 X num_boxes)
MichaelisMenten_KNO3     = zeros(num_E2Egroups, 1, num_boxes); % K     = NO3 half-saturation constant;          (mmol N/m3);  (3D matrix: num_E2Egroups X 1 X num_boxes)
MichaelisMenten_KNH4     = zeros(num_E2Egroups, 1, num_boxes); % K     = NH4 half-saturation constant;          (mmol N/m3);  (3D matrix: num_E2Egroups X 1 X num_boxes)
MichaelisMenten_alpha    = zeros(num_E2Egroups, 1, num_boxes); % alpha = initial slope of light response curve; (m2/W/d);     (3D matrix: num_E2Egroups X 1 X num_boxes)
MichaelisMenten_psi      = zeros(num_E2Egroups, 1, num_boxes); % psi   = NO3 uptake inhibition by NH4;          (m3/mmole N); (3D matrix: num_E2Egroups X 1 X num_boxes)
% MichaelisMenten_w        = zeros(num_E2Egroups, 1, num_boxes); % ALREADY DEFINED & APPLIED IN STEP 6g as SinkRate 3D matrix: num_t X num_E2Egroups X num_boxes); w     = sinking rate; (m/d); (3D matrix: num_E2Egroups X 1 X num_boxes)
% MichaelisMenten_eta      = zeros(num_E2Egroups, 1, num_boxes); % ALREADY DEFINED & APPLIED IN STEP 8e; eta   = non-grazing mortality;                 (1/d);        (3D matrix: num_E2Egroups X 1 X num_boxes)


% % step 10b: define MichaelisMenten parameter values for each primary producer
% %          NOTE: allow no nutrient uptake in sub-surface boxes; MichaelisMenten_Vmax(:, :, looky_SubSurfaceBoxes) = 0;
% MichaelisMenten_Vmax(SmlPhyto_rowclm, 1, [1 looky_SurfaceBoxes])    = 0.42;     % Vmax  = maximum nutrient uptake rate;          (1/d);        (3D matrix: num_E2Egroups X 1 X num_boxes)
% MichaelisMenten_KNO3(SmlPhyto_rowclm, 1, [1 looky_SurfaceBoxes])    = 0.14;     % K     = NO3 half-saturation constant;          (mmol N/m3);  (3D matrix: num_E2Egroups X 1 X num_boxes)
% MichaelisMenten_KNH4(SmlPhyto_rowclm, 1, [1 looky_SurfaceBoxes])    = 0.14;     % K     = NH4 half-saturation constant;          (mmol N/m3);  (3D matrix: num_E2Egroups X 1 X num_boxes)
% MichaelisMenten_alpha(SmlPhyto_rowclm, 1, [1 looky_SurfaceBoxes])   = 0.025;    % alpha = initial slope of light response curve; (m2/W/d);     (3D matrix: num_E2Egroups X 1 X num_boxes)
% MichaelisMenten_psi(SmlPhyto_rowclm, 1, [1 looky_SurfaceBoxes])     = 0;        % psi   = NO3 uptake inhibition by NH4;          (m3/mmole N); (3D matrix: num_E2Egroups X 1 X num_boxes)
% 
% MichaelisMenten_Vmax(LargePhyto_rowclm, 1, [1 looky_SurfaceBoxes])  = 1.5;      % Vmax  = maximum nutrient uptake rate;          (1/d);        (3D matrix: num_E2Egroups X 1 X num_boxes)
% MichaelisMenten_KNO3(LargePhyto_rowclm, 1, [1 looky_SurfaceBoxes])  = 1.2;      % K     = NO3 half-saturation constant;          (mmol N/m3);  (3D matrix: num_E2Egroups X 1 X num_boxes)
% MichaelisMenten_KNH4(LargePhyto_rowclm, 1, [1 looky_SurfaceBoxes])  = 1.2;      % K     = NH4 half-saturation constant;          (mmol N/m3);  (3D matrix: num_E2Egroups X 1 X num_boxes)
% MichaelisMenten_alpha(LargePhyto_rowclm, 1, [1 looky_SurfaceBoxes]) = 0.0375;   % alpha = initial slope of light response curve; (m2/W/d);     (3D matrix: num_E2Egroups X 1 X num_boxes)
% MichaelisMenten_psi(LargePhyto_rowclm, 1, [1 looky_SurfaceBoxes])   = 1.46;     % psi   = NO3 uptake inhibition by NH4;          (m3/mmole N); (3D matrix: num_E2Egroups X 1 X num_boxes)


% % step 10c: select only the primary producer rows -------------------------
% MichaelisMenten_Vmax                        = MichaelisMenten_Vmax(looky_PrimaryProducer, 1, :);  % Vmax  = maximum nutrient uptake rate;          (1/d);        (3D matrix: num_PrimaryProducers X 1 X num_boxes)
% MichaelisMenten_KNO3                        = MichaelisMenten_KNO3(looky_PrimaryProducer, 1, :);  % KNO3  = NO3 half-saturation constant;          (mmol N/m3);  (3D matrix: num_PrimaryProducers X 1 X num_boxes)
% MichaelisMenten_KNH4                        = MichaelisMenten_KNH4(looky_PrimaryProducer, 1, :);  % KNH4  = NH4 half-saturation constant;          (mmol N/m3);  (3D matrix: num_PrimaryProducers X 1 X num_boxes)
% MichaelisMenten_alpha                       = MichaelisMenten_alpha(looky_PrimaryProducer, 1, :); % alpha = initial slope of light response curve; (m2/W/d);     (3D matrix: num_PrimaryProducers X 1 X num_boxes)
% MichaelisMenten_psi                         = MichaelisMenten_psi(looky_PrimaryProducer, 1, :);   % psi   = NO3 uptake inhibition by NH4;          (m3/mmole N); (3D matrix: num_PrimaryProducers X 1 X num_boxes)


% step 10d: variables needed for ODE --------------------------------------
ODEinput.MichaelisMenten_Vmax               = MichaelisMenten_Vmax;          % (3D matrix: num_PrimaryProducers X 1 X num_boxes)
ODEinput.MichaelisMenten_KNO3               = MichaelisMenten_KNO3;          % (3D matrix: num_PrimaryProducers X 1 X num_boxes)
ODEinput.MichaelisMenten_KNH4               = MichaelisMenten_KNH4;          % (3D matrix: num_PrimaryProducers X 1 X num_boxes)
ODEinput.MichaelisMenten_alpha              = MichaelisMenten_alpha;         % (3D matrix: num_PrimaryProducers X 1 X num_boxes)
ODEinput.MichaelisMenten_psi                = MichaelisMenten_psi;           % (3D matrix: num_PrimaryProducers X 1 X num_boxes)





% *************************************************************************
% STEP 11: run ODE for each MonteCarlo model-------------------------------
% step 11a: initialize solution time variable -----------------------------
store_T     = zeros(num_t, 1, num_webMonteCarlo);	% time variable; (3D matrix: num_t X 1 X num_webMonteCarlo)


% step 11b: loop through each MonteCarlo model ----------------------------
for MonteCarlo_loop = 1:num_webMonteCarlo
% for MonteCarlo_loop = 1:21   % QQQ for TE-tuning
 
    ModelNumber     = MonteCarlo_loop;                                      % select the MonteCarlo_loop model
    saveFile        = [SaveFile_directory SaveFile_label '_MCnum_' num2str(MonteCarlo_loop) '_' date '.mat'];
    display(['run ' num2str(MonteCarlo_loop) ' of ' num2str(num_webMonteCarlo)])
    
    
    % step 11c: prep the Functional Response terms ------------------------
    CV_FunctionalResponse                  = ones(1, num_E2Egroups) * 0;    % SSS --> set uncertainty level for functional response terms; (horizontal vector: 1 X producers)
    FunctionalResponseParams               = f_FunctionalResponse_MonteCarlo_09122016(ECOTRAN, ODEinput, CV_FunctionalResponse);
    FunctionalResponseParams               = FunctionalResponseParams * 0;  % SSS force to linear for shelf comparison study!!!
    ODEinput.FunctionalResponseParams      = FunctionalResponseParams;      % pack to send to ODE; (vulnerability of producer, m_p); (3D matrix: consumers X producers X num_boxes)
    
    
    % step 11d: pick current MonteCarlo model -----------------------------
    current_EnergyBudget_matrix             = EnergyBudget_matrix(:, :,               ModelNumber);         % (2D matrix: num_E2Egroups X num_E2Egroups)
    current_Qbudget_feces                   = BioenergeticBudget_feces(:, :,          ModelNumber);         % (2D matrix: num_t X num_E2Egroups)
    current_Qbudget_metabolism              = BioenergeticBudget_metabolism(:, :,     ModelNumber);         % (2D matrix: num_t X num_E2Egroups)
    current_Qbudget_predation               = BioenergeticBudget_predation(:, :,      ModelNumber);         % (2D matrix: num_t X num_E2Egroups)
    current_Qbudget_eggs                    = BioenergeticBudget_eggs(:, :,           ModelNumber);         % (2D matrix: num_t X num_E2Egroups)
    current_Qbudget_OtherMortality          = BioenergeticBudget_OtherMortality(:, :, ModelNumber);         % (2D matrix: num_t X num_E2Egroups)
    current_Qbudget_BA                      = BioenergeticBudget_BA(:, :,             ModelNumber);         % (2D matrix: num_t X num_E2Egroups)
    current_Qbudget_EM                      = BioenergeticBudget_EM(:, :,             ModelNumber);         % (2D matrix: num_t X num_E2Egroups)
    current_Biomass                         = EwE_Biomass(:,                          1);                   % (t WWT/km2); (vertical vector: num_E2Egroups X 1)

    current_SpecificGrowthRate              = SpecificGrowthRate(:, :,                      ModelNumber);   % (1/d); (2D matrix: num_t X num_E2Egroups)
    current_SpecificConsumptionRate         = SpecificConsumptionRate(:, :,                 ModelNumber);   % (1/d); (2D matrix: num_t X num_E2Egroups)
    current_TransferEfficiency              = TransferEfficiency(ModelNumber,           1:num_E2Egroups);   % (horizontal vector: 1 X num_E2Egroups)
    current_DetritusFate_feces              = DetritusFate_feces(:, :,                      1);             % (2D matrix: 2 X num_E2Egroups)
    current_DetritusFate_senescence         = DetritusFate_senescence(:, :,                 1);             % (2D matrix: 2 X num_E2Egroups)
    current_ExcretionFate                   = ExcretionFate(:, :,                           1);             % (2D matrix: 2 X num_E2Egroups)
    current_EggFate                         = EggFate(:, :,                                 1);             % (2D matrix: num_eggs X num_E2Egroups)
    current_PB                              = EwE_PB(:,                                     1);             % (1/y); (vertical vector: num_E2Egroups X 1)
%     current_QB                              = EwE_QB(:,                                     ModelNumber);   % (not used, 6-3-16); (1/y); (vertical vector: num_E2Egroups X 1)


    % step 11e: build-up spatial sub-models -------------------------------
    current_Biomass                         = repmat(current_Biomass, [1, num_boxes]);                                          % (t WWT/km2); (2D matrix: groups X num_boxes)
    current_Biomass                         = current_Biomass .* repmat(ODEinput.spatial_BiomassScalers, [num_E2Egroups 1]);    % (t WWT/km2); (2D matrix: groups X num_boxes)
    current_Biomass(2:end, [1 4 5])         = 0;                                                                                % NOTE: special case for basin
        
    % OPTION 1: use the same web across the shelf
        current_EnergyBudget_matrix             = repmat(current_EnergyBudget_matrix, [1, 1, num_boxes]);   % use for a single definition for the EnergyBudget_matrix
        current_EnergyBudget_matrix             = current_EnergyBudget_matrix .* EnergyBudget_BoxType;      % adjust sub-surface EnergyBudget matrices; allow only certain recycling processes in sub-surface boxes; (fraction); (3D matrix: num_E2Egroups X num_E2Egroups X num_boxes)
    
% % %     % OPTION 2: use independently defined webs for each shelf zone
% % %     %           use for multiple definitions for the EnergyBudget_matrix
% % %         current_EnergyBudget_matrix             = zeros(num_E2Egroups, num_E2Egroups, num_boxes); initialize; (3D matrix: num_E2Egroups X num_E2Egroups X num_boxes)
% % %         current_EnergyBudget_matrix(:, :, 1)    = current_EnergyBudget_matrix_inner;
% % %         current_EnergyBudget_matrix(:, :, 2)    = current_EnergyBudget_matrix_mid;
% % %         current_EnergyBudget_matrix(:, :, 3)    = current_EnergyBudget_matrix_mid;
% % %         current_EnergyBudget_matrix(:, :, 4)    = current_EnergyBudget_matrix_outer;
% % %         current_EnergyBudget_matrix(:, :, 5)    = current_EnergyBudget_matrix_outer;
% % %         current_EnergyBudget_matrix             = current_EnergyBudget_matrix .* EnergyBudget_BoxType; % adjust sub-surface EnergyBudget matrices; allow only certain recycling processes in sub-surface boxes; (fraction); (3D matrix: num_E2Egroups X num_E2Egroups X num_boxes)
    

    current_Qbudget_feces                   = repmat(current_Qbudget_feces, [1, 1, num_boxes]);             % (3D matrix: num_t X num_E2Egroups X num_boxes)
    current_Qbudget_metabolism              = repmat(current_Qbudget_metabolism, [1, 1, num_boxes]);        % (3D matrix: num_t X num_E2Egroups X num_boxes)
    current_Qbudget_predation               = repmat(current_Qbudget_predation, [1, 1, num_boxes]);         % (3D matrix: num_t X num_E2Egroups X num_boxes)
    current_Qbudget_eggs                    = repmat(current_Qbudget_eggs, [1, 1, num_boxes]);              % (3D matrix: num_t X num_E2Egroups X num_boxes)
    current_Qbudget_OtherMortality          = repmat(current_Qbudget_OtherMortality, [1, 1, num_boxes]);    % (3D matrix: num_t X num_E2Egroups X num_boxes)
    current_Qbudget_BA                      = repmat(current_Qbudget_BA, [1, 1, num_boxes]);                % (3D matrix: num_t X num_E2Egroups X num_boxes)
    current_Qbudget_EM                      = repmat(current_Qbudget_EM, [1, 1, num_boxes]);                % (3D matrix: num_t X num_E2Egroups X num_boxes)
    
    current_DetritusFate_feces              = repmat(current_DetritusFate_feces, [1, 1, num_boxes]);        % (3D matrix: 2 X num_E2Egroups X num_boxes)
    current_DetritusFate_senescence         = repmat(current_DetritusFate_senescence, [1, 1, num_boxes]);   % (3D matrix: 2 X num_E2Egroups X num_boxes)
    current_ExcretionFate                   = repmat(current_ExcretionFate, [1, 1, num_boxes]);             % (3D matrix: 2 X num_E2Egroups X num_boxes)
    current_EggFate                         = repmat(current_EggFate, [1, 1, num_boxes]);                   % (3D matrix: num_eggs X num_E2Egroups X num_boxes)
    current_SpecificGrowthRate              = repmat(current_SpecificGrowthRate, [1, 1, num_boxes]);        % (3D matrix: num_t X num_E2Egroups X num_boxes)
    current_SpecificConsumptionRate         = repmat(current_SpecificConsumptionRate, [1, 1, num_boxes]);   % (3D matrix: num_t X num_E2Egroups X num_boxes)
    current_TransferEfficiency              = repmat(current_TransferEfficiency, [1, 1, num_boxes]);        % (3D matrix: 1 X num_E2Egroups X num_boxes)
    
    
    % step 11f: sinking fluxes --------------------------------------------
    %           fraction of consumption inflow sinking OUT of source box
    %           NOTE: SpecificGrowthRate = SpecificConsumptionRate for primary producers
    current_SinkFrac = SinkRate .* (1./BoxHeight_repmat) .* (1./current_SpecificConsumptionRate); % (unitless); (3D matrix: num_t X num_E2Egroups X num_boxes)
    
    
    % step 11g: variables needed for ODE ----------------------------------
    ODEinput.EnergyBudget_matrix               = current_EnergyBudget_matrix;       % (3D matrix: num_E2Egroups X num_E2Egroups X num_boxes)
    ODEinput.EnergyBudget_matrix(3, looky_ULTIMATEdetritus, :) = 0.5;               % make ULTIMATE detritus conversion same as pelagic detr conversion
    ODEinput.Biomass                           = current_Biomass;                   % (t WWT/km2); (2D matrix: groups X num_boxes)
    ODEinput.BioenergeticBudget_feces          = current_Qbudget_feces;             % (3D matrix: num_t X num_E2Egroups X num_boxes)
    ODEinput.BioenergeticBudget_metabolism     = current_Qbudget_metabolism;        % (3D matrix: num_t X num_E2Egroups X num_boxes)
    ODEinput.BioenergeticBudget_predation      = current_Qbudget_predation;         % (3D matrix: num_t X num_E2Egroups X num_boxes)
    ODEinput.BioenergeticBudget_eggs           = current_Qbudget_eggs;              % (3D matrix: num_t X num_E2Egroups X num_boxes)
    ODEinput.BioenergeticBudget_OtherMortality = current_Qbudget_OtherMortality;    % (3D matrix: num_t X num_E2Egroups X num_boxes)
    ODEinput.BioenergeticBudget_BA             = current_Qbudget_BA;                % (3D matrix: num_t X num_E2Egroups X num_boxes)
    ODEinput.BioenergeticBudget_EM             = current_Qbudget_EM;                % (3D matrix: num_t X num_E2Egroups X num_boxes)
    ODEinput.SpecificGrowthRate                = current_SpecificGrowthRate;        % (1/d); (3D matrix: num_t X num_E2Egroups X num_boxes)
    ODEinput.SpecificConsumptionRate           = current_SpecificConsumptionRate;   % (1/d); (3D matrix: num_t X num_E2Egroups X num_boxes)
    ODEinput.TransferEfficiency                = current_TransferEfficiency;        % (3D matrix: 1 X num_E2Egroups X num_boxes)
    ODEinput.DetritusFate_feces                = current_DetritusFate_feces;        % (3D matrix: 2 X num_E2Egroups X num_boxes)
    ODEinput.DetritusFate_senescence           = current_DetritusFate_senescence;   % (3D matrix: 2 X num_E2Egroups X num_boxes)
    ODEinput.ExcretionFate                     = current_ExcretionFate;             % (3D matrix: 2 X num_E2Egroups X num_boxes)
    ODEinput.EggFate                           = current_EggFate;                   % (3D matrix: num_eggs X num_E2Egroups X num_boxes)
    ODEinput.SinkFrac                          = current_SinkFrac;                  % (unitless); (3D matrix: num_t X num_E2Egroups X num_boxes)
%     ODEinput.PB                                = current_PB;                        % (1/y); (vertical vector: num_E2Egroups X 1)
%     ODEinput.QB                                = current_QB;                        % (1/y); (vertical vector: num_E2Egroups X 1)
    ODEinput.PhysicalLossFraction              = PhysicalLossFraction;              % (2D matrix: time X groups)
    ODEinput.Production_input                  = Production_input;                  % (mmole N/m3/d); (3D matrix: num_t X num_E2Egroups X num_boxes)    
    

    % step 11h: calculate INITIAL production rate conditions --------------
    %           NOTE: (INITIAL production = consumption inflow)
    
% % %     % METHOD 1: use for driving with primary production defined by Michaelis-Menton uptake
% % %     %           replicate nutients for each primary producer
% % %     %           QQQ possible to switch from initialNO3 to NO3_t at t_mean
% % %     InitialDriver_rowclm                                = looky_PrimaryProducer;                                 % define driver for initial production rates
% % %     Biomass_PrimaryProducer_WWT                         = current_Biomass(looky_PrimaryProducer, :);             % EwE_Biomass of primary producers in current MonteCarlo model; (t WWT/km2); (2D matrix: num_PrimaryProducers X num_boxes)
% % %     Biomass_Phytoplankton_WWT                           = current_Biomass(looky_Phytoplankton, :);               % EwE_Biomass of Phytoplankton in current MonteCarlo model;     (t WWT/km2); (2D matrix: num_Phytoplankton X num_boxes)
% % %     Biomass_Macroalgae_WWT                              = current_Biomass(looky_Macroalgae, :);                  % EwE_Biomass of Macroalgae in current MonteCarlo model;        (t WWT/km2); (2D matrix: num_Macroalgae X num_boxes)
% % %     PB_PrimaryProducer                                  = current_PB(looky_PrimaryProducer);                     % EwE_PB of primary producers in current MonteCarlo model;      (1/y);       (vertical vector: num_PrimaryProducers X 1); FFF allow for PB changes throughout the year
% % %     PB_Phytoplankton                                    = current_PB(looky_Phytoplankton);                       % EwE_PB of Phytoplankton in current MonteCarlo model;          (1/y);       (vertical vector: num_Phytoplankton X 1);    FFF allow for PB changes throughout the year
% % %     PB_Macroalgae                                       = current_PB(looky_Macroalgae);                          % EwE_PB of Macroalgae in current MonteCarlo model;             (1/y);       (vertical vector: num_Macroalgae X 1);       FFF allow for PB changes throughout the year
% % %     % primary producer biomass conversion from (t WWT/km2) to (mmoles N/m3)
% % %     Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_WWT;                           % (t WWT/km2); (2D matrix: num_PrimaryProducers X num_boxes)
% % %     EuphoticDepth_t                                     = interp1(t_grid, EuphoticDepth, t_initial);             % euphotic zone depth @ t; (m); (horizontal vector: 1 X num_boxes)
% % %     EuphoticDepth_t                                     = repmat(EuphoticDepth_t, [num_PrimaryProducers, 1]);    % replicate box heights for each primary producer; (m); (2D matrix: num_PrimaryProducers X num_boxes);
% % %     Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * (1/(1000*1000));           % area to volumetric conversion; (t WWT/m2);  (2D matrix: num_PrimaryProducers X num_boxes);
% % %     Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t .* (1./EuphoticDepth_t);     % area to volumetric conversion; (t WWT/m3);  (2D matrix: num_PrimaryProducers X num_boxes); NOTE use of BoxHeight instead of MLD because we are starting out with phyto biomasses defined as vertically integrated over whole boxes
% % %     Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * 1000000;                   % (g WWT/m3);   (2D matrix: num_PrimaryProducers X num_boxes);
% % %     Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * 1000;                      % (mg WWT/m3);  (2D matrix: num_PrimaryProducers X num_boxes);
% % %     Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * (1/WWT_to_C);              % (mg C/m3);    (2D matrix: num_PrimaryProducers X num_boxes);
% % %     Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * (1/atomic_mass_C);         % (mmole C/m3); (2D matrix: num_PrimaryProducers X num_boxes);
% % %     Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * (1/C_to_N_phytoplankton);  % (mmole N/m3); (2D matrix: num_PrimaryProducers X num_boxes);
% % % 
% % %     % special case to accomodate any macroalgae
% % %     Production_PrimaryProducer_WWT                      = Biomass_PrimaryProducer_WWT .* repmat(PB_PrimaryProducer, [1, num_boxes]); % (t WWT/km2/y); (2D matrix: num_PrimaryProducers X num_boxes)
% % %     Production_Phytoplankton_WWT                        = Biomass_Phytoplankton_WWT   .* repmat(PB_Phytoplankton,   [1, num_boxes]); % (t WWT/km2/y); (2D matrix: num_Phytoplankton X num_boxes)
% % %     Production_Macroalgae_WWT                           = Biomass_Macroalgae_WWT      .* repmat(PB_Macroalgae,      [1, num_boxes]); % (t WWT/km2/y); (2D matrix: num_Macroalgae X num_boxes)
% % %     ProductionFraction_macroalgae                       = Production_Macroalgae_WWT   ./ repmat(sum(Production_PrimaryProducer_WWT), [num_Macroalgae, 1]); % macroalgae fraction(s) of total primary production based on EwE P=B*PB; (2D matrix: num_Macroalgae X num_boxes)
% % %     ProductionFraction_macroalgae(isnan(ProductionFraction_macroalgae)) = 0;                                                         % fix div/0 NaNs
% % %     ProductionFraction_macroalgae                       = reshape(ProductionFraction_macroalgae, [num_Macroalgae, 1, num_boxes]);    % (3D matrix: num_Macroalgae X 1 X num_boxes)
% % % 
% % %     Biomass_PrimaryProducer_t                           = reshape(Biomass_PrimaryProducer_t, [num_PrimaryProducers, 1, num_boxes]); % (mmole N/m3); (3D matrix: num_PrimaryProducers X 1 X num_boxes)
% % %     NO3_t                                               = repmat(initialNO3, [num_PrimaryProducers, 1]);                            % (mmoles NO3/m3); (2D matrix: num_PrimaryProducers X num_boxes)
% % %     NH4_t                                               = repmat(initialNH4, [num_PrimaryProducers, 1]);                            % (mmoles NH4/m3); (2D matrix: num_PrimaryProducers X num_boxes)
% % %     NO3_t                                               = reshape(NO3_t, [num_PrimaryProducers, 1, num_boxes]);                     % (mmole N/m3); (3D matrix: num_E2Egroups X 1 X num_boxes)
% % %     NH4_t                                               = reshape(NH4_t, [num_PrimaryProducers, 1, num_boxes]);                     % (mmole N/m3); (3D matrix: num_E2Egroups X 1 X num_boxes)
% % %     Io_t                                                = interp1(t_grid, Io, t_mean);                                              % surface PAR light intensity @ t; daily integrated solar raditation at ocean surface averaged across 24 hours; (W m^-2 h^-1); (scaler); NOTE: using t_mean rather than t_initial
% % %     MLD_t                                               = interp1(t_grid, MLD, t_mean);                                             % MLD @ t; (m); (scaler)
% % %     NH4fraction_bnth                                    = zeros(num_PrimaryProducers, 1, num_boxes);                                % value 0 - 1; (3D matrix: num_PrimaryProducers X 1 X num_boxes); (for Michaelis-Menten calcs); for initial conditions, any NH4 is asigned as pelagic
% % % 
% % %     [Q_cp_NO3, Q_cp_NH4, Q_cp_plgcNH4, Q_cp_bnthNH4, PB_MichaelisMenten] = f_MichaelisMenten_05152016(ODEinput, Biomass_PrimaryProducer_t, NO3_t, NH4_t, NH4fraction_bnth, Io_t, MLD_t); % phytoplankton uptake rate of NO3 & NH4 (mmole N/m3/d) & PB @ t as calculated from MichaelisMenton uptake (1/y); (3D matrix: num_PrimaryProducers X 1 X num_boxes)
% % %     initialPrimaryProduction                            = Q_cp_NO3 + Q_cp_NH4;                                                      % phytoplankton production rate; (mmole N/m3/d); (3D matrix: num_PrimaryProducers X 1 X num_boxes)
% % %     initialPrimaryProduction                            = squeeze(initialPrimaryProduction);                                        % (mmole N/m3/d); (2D matrix: num_PrimaryProducers X num_boxes)
% % %     InitialProductionDriver                             = zeros(num_E2Egroups, num_boxes);                                          % initialize; (2D matrix: num_E2Egroups X num_boxes)
% % % 	  InitialProductionDriver(InitialDriver_rowclm, :)    = initialPrimaryProduction;                                                 % (2D matrix: num_E2Egroups X num_boxes)
% % %     if num_Macroalgae > 0
% % %         InitialProductionDriver(looky_Macroalgae, :) = repmat(sum(initialPrimaryProduction), [num_Macroalgae, 1]) .* ProductionFraction_macroalgae; % (2D matrix: num_E2Egroups X num_boxes)
% % %     end
% % %     InitialProductionDriver                             = reshape(InitialProductionDriver, [num_E2Egroups, 1, num_boxes]);          % (3D matrix: num_E2Egroups X 1 X num_boxes)
% % %     InitialProductionDriver                             = reshape(InitialProductionDriver, [1, num_E2Egroups, num_boxes]);          % (3D matrix: 1 X num_E2Egroups X num_boxes) 


    % METHOD 2: use for driving initial model conditions with primary production defined by P = [(P/B) * B]
    %           NOTE: actually Q = [(Q/B) * B] because P and Q are same thing for primary producers
    InitialDriver_rowclm                                = looky_PrimaryProducer;                                % define driver for initial production rates
    Biomass_PrimaryProducer_WWT                         = current_Biomass(looky_PrimaryProducer, :);            % EwE_Biomass of primary producers in current MonteCarlo model; (t WWT/km2); (2D matrix: num_PrimaryProducers X num_boxes)
    Biomass_Phytoplankton_WWT                           = current_Biomass(looky_Phytoplankton, :);              % EwE_Biomass of Phytoplankton in current MonteCarlo model;     (t WWT/km2); (2D matrix: num_Phytoplankton X num_boxes)
    Biomass_Macroalgae_WWT                              = current_Biomass(looky_Macroalgae, :);                 % EwE_Biomass of Macroalgae in current MonteCarlo model;        (t WWT/km2); (2D matrix: num_Macroalgae X num_boxes)
    PB_PrimaryProducer                                  = current_PB(looky_PrimaryProducer);                    % EwE_PB of primary producers in current MonteCarlo model;      (1/y);       (vertical vector: num_PrimaryProducers X 1); FFF allow for PB changes throughout the year
    PB_Phytoplankton                                    = current_PB(looky_Phytoplankton);                      % EwE_PB of Phytoplankton in current MonteCarlo model;          (1/y);       (vertical vector: num_Phytoplankton X 1);    FFF allow for PB changes throughout the year
    PB_Macroalgae                                       = current_PB(looky_Macroalgae);                         % EwE_PB of Macroalgae in current MonteCarlo model;             (1/y);       (vertical vector: num_Macroalgae X 1);       FFF allow for PB changes throughout the year
    
    % primary producer biomass conversion from (t WWT/km2) to (mmoles N/m3)
    Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_WWT;                          % (t WWT/km2); (2D matrix: num_PrimaryProducers X num_boxes)
    EuphoticDepth_t                                     = interp1(t_grid, EuphoticDepth, t_initial);            % euphotic zone depth @ t; (m); (horizontal vector: 1 X num_boxes)
    EuphoticDepth_t                                     = repmat(EuphoticDepth_t, [num_PrimaryProducers, 1]);   % replicate box heights for each primary producer; (m); (2D matrix: num_PrimaryProducers X num_boxes);
    Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * (1/(1000*1000));          % area to volumetric conversion; (t WWT/m2);  (2D matrix: num_PrimaryProducers X num_boxes);
    Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t .* (1./EuphoticDepth_t);    % area to volumetric conversion; (t WWT/m3);  (2D matrix: num_PrimaryProducers X num_boxes); NOTE use of BoxHeight instead of MLD because we are starting out with phyto biomasses defined as vertically integrated over whole boxes
    Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * 1000000;                  % (g WWT/m3);   (2D matrix: num_PrimaryProducers X num_boxes);
    Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * 1000;                     % (mg WWT/m3);  (2D matrix: num_PrimaryProducers X num_boxes);
    Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * (1/WWT_to_C);             % (mg C/m3);    (2D matrix: num_PrimaryProducers X num_boxes);
    Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * (1/atomic_mass_C);        % (mmole C/m3); (2D matrix: num_PrimaryProducers X num_boxes);
    Biomass_PrimaryProducer_t                           = Biomass_PrimaryProducer_t * (1/C_to_N_phytoplankton); % (mmole N/m3); (2D matrix: num_PrimaryProducers X num_boxes);
    
    % special case to accomodate any macroalgae
    Production_PrimaryProducer_WWT                      = Biomass_PrimaryProducer_WWT .* repmat(PB_PrimaryProducer, [1, num_boxes]); % (t WWT/km2/y); (2D matrix: num_PrimaryProducers X num_boxes)
    Production_Phytoplankton_WWT                        = Biomass_Phytoplankton_WWT   .* repmat(PB_Phytoplankton,   [1, num_boxes]); % (t WWT/km2/y); (2D matrix: num_Phytoplankton X num_boxes)
    Production_Macroalgae_WWT                           = Biomass_Macroalgae_WWT      .* repmat(PB_Macroalgae,      [1, num_boxes]); % (t WWT/km2/y); (2D matrix: num_Macroalgae X num_boxes)
    ProductionFraction_macroalgae                       = Production_Macroalgae_WWT   ./ repmat(sum(Production_PrimaryProducer_WWT), [num_Macroalgae, 1]); % macroalgae fraction(s) of total primary production based on EwE P=B*PB; (2D matrix: num_Macroalgae X num_boxes)
    ProductionFraction_macroalgae(isnan(ProductionFraction_macroalgae)) = 0; % fix div/0 NaNs
    ProductionFraction_macroalgae                       = reshape(ProductionFraction_macroalgae, [num_Macroalgae, 1, num_boxes]); % (3D matrix: num_Macroalgae X 1 X num_boxes)
    initialPrimaryProduction                            = Biomass_PrimaryProducer_t .* repmat((PB_PrimaryProducer/365), [1, num_boxes]);    % phytoplankton production rate; (mmoles N/m3/d); (2D matrix: num_PrimaryProducers X num_boxes)

    % initial production (actually consumption inflow) driver vector for each Box; (mmole N/m3/d); (3D matrix: 1 X num_groups X num_boxes)
    InitialDriver_rowclm                                = looky_PrimaryProducer;
    InitialProductionDriver                             = zeros(1, num_E2Egroups, num_boxes);                                               % initialize DriverProductionVector;                (3D matrix: 1 X num_E2Egroups X num_boxes)
    InitialProductionDriver(1, InitialDriver_rowclm, :) = reshape(initialPrimaryProduction, [1, num_PrimaryProducers, num_boxes]); % plug in primary production rates; (mmole N/m3/d); (3D matrix: 1 X num_E2Egroups X num_boxes)
    
    
    % finalize initial condition calculations following METHOD 1 or METHOD 2 
    Production_initial                                  = f_InitialProductionRates_05112016(ODEinput, InitialProductionDriver, t_initial);  % initial or mean production rates (actually consumption inflow) (mmole N/m3/d); (2D matrix: num_E2Egroups X num_boxes)
    Production_initial(looky_NO3, :)                    = initialNO3;                                                                       % append NO3 concentration values to NO3 rows; NOTE the inconsistency in row definitions, nutrient values are concentrations but all other values are production rates!!!
    Production_initial(looky_NO3, [2 3 5])              = 14.85;                                                                            % NOTE: special NorSea case - tuned based on 20-yr mean summer burn-in values with inert NO3 tracer; append NO3 concentration values to NO3 rows; NOTE the inconsistency in row definitions, nutrient values are concentrations but all other values are production rates!!!
    Production_initial                                  = reshape(Production_initial, [num_E2Egroups, 1, num_boxes]);                       % replicate boxes as layers; (3D matrix: num_E2Egroups X 1 X num_boxes); (mmole N/m3/d)
    ProductionC_initial_repmat                          = repmat(Production_initial,   [1, E2E_clms, 1]);                                   % (3D matrix: num_E2Egroups X num_E2Egroups X num_boxes); (mmole N/m3/d); NOTE: vertical vectors 
    
    
    % step 11i: calculate BOUNDARY biomass conditions ---------------------
    %           NOTE: there are 3 options

% % %     % OPTION 1: ocean biomass conditions at time t are estimated from outer-shelf sub-domain food webs as driven by NO3 input time-series
% % %     %           NOTE: SubSurface boxes only have NO3 and plgcNH4
% % %     %           NOTE: could redefine SubSurface and River boxes as a set fraction of Surface biomasses
% % %     %           NOTE: River biomass is not used, River boundary is assumed to be reflective
% % %     %           NOTE: use with function f_ECOTRANode_DefinedBoundary_basin_08032017
% % %     StaticProduction_OceanSurface                   = f_StaticProductionTimeseries_09042017(ODEinput, ECOTRANphysics, Production_input, looky_OffshoreSurfaceBox);    	% (mmole N/m3/d); (2D matrix: num_E2Egroups X num_t)
% % %     StaticProduction_OceanSubSurface                = f_StaticProductionTimeseries_09042017(ODEinput, ECOTRANphysics, Production_input, looky_OffshoreSubSurfaceBox);	% (mmole N/m3/d); (2D matrix: num_E2Egroups X num_t)
% % %     StaticProduction_River                          = f_StaticProductionTimeseries_09042017(ODEinput, ECOTRANphysics, Production_input, looky_RiverFluxBox);            % (mmole N/m3/d); (2D matrix: num_E2Egroups X num_t)
% % %     
% % %     StaticBiomass_OceanSurface                      = StaticProduction_OceanSurface    ./ current_SpecificConsumptionRate(:, :, looky_OffshoreSurfaceBox)'; % use Q/B value to convert rates to standing stock biomass; (mmole N/m3); (2D matrix: num_E2Egroups X num_t); NOTE transpose of current_SpecificConsumptionRate
% % %     StaticBiomass_OceanSubSurface                   = StaticProduction_OceanSubSurface ./ current_SpecificConsumptionRate(:, :, looky_OffshoreSurfaceBox)'; % use Q/B value to convert rates to standing stock biomass; (mmole N/m3); (2D matrix: num_E2Egroups X num_t); NOTE transpose of current_SpecificConsumptionRate
% % %     StaticBiomass_River                             = StaticProduction_River           ./ current_SpecificConsumptionRate(:, :, looky_OffshoreSurfaceBox)'; % use Q/B value to convert rates to standing stock biomass; (mmole N/m3); (2D matrix: num_E2Egroups X num_t); NOTE transpose of current_SpecificConsumptionRate
% % %     
% % %     StaticBiomass_OceanSubSurface                   = StaticBiomass_OceanSurface * 0.1;                     % assume sub-surface plankton and detritus is 10% of surface values; (mmole N/m3); (2D matrix: num_E2Egroups X num_t)
% % %     
% % %     StaticBiomass_OceanSurface(looky_NO3, :)        = NO3_timeseries(:, looky_OffshoreSurfaceBox)';        	% plug NO3 concentrations into biomass time-series
% % %     StaticBiomass_OceanSubSurface(looky_NO3, :)     = NO3_timeseries(:, looky_OffshoreSubSurfaceBox)';    	% plug NO3 concentrations into biomass time-series
% % %     StaticBiomass_River(looky_NO3, :)               = NO3_timeseries(:, looky_RiverFluxBox)';             	% plug NO3 concentrations into biomass time-series
% % %     
% % %     StaticBiomass_OceanSubSurface(looky_plgcNH4, :)	= StaticBiomass_OceanSubSurface(looky_plgcNH4, :) + StaticBiomass_OceanSubSurface(looky_bnthNH4, :) + StaticBiomass_OceanSurface(looky_bnthNH4, :);    % move bnth NH4 from Surface to SubSurface
% % %     StaticBiomass_OceanSubSurface(looky_bnthNH4, :) = 0;
% % %     StaticBiomass_OceanSurface(looky_bnthNH4, :)    = 0;
% % %     
% % %     StaticBiomass_River(looky_plgcNH4, :)           = StaticBiomass_River(looky_plgcNH4, :)           + StaticBiomass_River(looky_bnthNH4, :);              % pool plgc and bnth NH4
% % %     StaticBiomass_River(looky_bnthNH4, :)           = 0;
% % %     
% % %     BoxBiomass_OceanSurface                         = StaticBiomass_OceanSurface;       % (mmole N/m3); (2D matrix: num_E2Egroups X num_t)
% % %     BoxBiomass_OceanSubSurface                      = StaticBiomass_OceanSubSurface;    % (mmole N/m3); (2D matrix: num_E2Egroups X num_t)
% % %     BoxBiomass_River                                = StaticBiomass_River;              % (mmole N/m3); (2D matrix: num_E2Egroups X num_t)
    
% % %     % OPTION 2: empty ocean (ocean only has NO3)
% % %     %           NOTE: run with option 1 activated
% % %     BoxBiomass_OceanSurface(looky_nonNO3, :)        = 0;                            % (mmole N/m3); (2D matrix: num_E2Egroups X num_t)
% % %     BoxBiomass_OceanSubSurface(looky_nonNO3, :)     = 0;                            % (mmole N/m3); (2D matrix: num_E2Egroups X num_t)
% % %     BoxBiomass_River(looky_nonNO3, :)               = 0;                            % (mmole N/m3); (2D matrix: num_E2Egroups X num_t)
    
    % OPTION 3: reflective boundary assumption (PREFERRED DEFAULT METHOD)
    %           NOTE: assign biomass values to ocean adjacent to the model domain (these boundary conditions used for horizontal mixing only)
    %           NOTE: this applies to nutrients (NO3) only. All other non_NO3 entries are zeroed out in the ODE
    %           NOTE: use with function f_ECOTRANode_ReflectiveBoundary_basin_05242017
    BoxBiomass_OceanSurface                             = Production_initial(:, 1, looky_OffshoreSurfaceBox);    % use Production_initial of offshore boxes to define ocean nutrient concentrations; (vertical vector: num_E2Egroups X 1); (mmole N/m3);
    BoxBiomass_OceanSubSurface                          = Production_initial(:, 1, looky_OffshoreSubSurfaceBox); % use Production_initial of offshore boxes to define ocean nutrient concentrations; (vertical vector: num_E2Egroups X 1); (mmole N/m3);
    BoxBiomass_River                                    = Production_initial(:, 1, looky_RiverFluxBox);          % use Production_initial of offshore boxes to define ocean nutrient concentrations; (vertical vector: num_E2Egroups X 1); (mmole N/m3);
    
    
    % step 11j: pack more variables needed for ODE ------------------------
    ODEinput.Production_initial                         = Production_initial;               % (mmole N/m3/d); (3D matrix: num_E2Egroups X 1 X num_boxes)
    ODEinput.ProductionC_initial_repmat                 = ProductionC_initial_repmat;       % (mmole N/m3/d); (3D matrix: num_E2Egroups X num_E2Egroups X num_boxes); NOTE: vertical vectors 
    ODEinput.ProductionFraction_macroalgae              = ProductionFraction_macroalgae;    % (3D matrix: num_Macroalgae X 1 X num_boxes)
    ODEinput.BoxBiomass_OceanSurface                    = BoxBiomass_OceanSurface;          % (mmole N/m3); (2D matrix: num_E2Egroups X num_t)
    ODEinput.BoxBiomass_OceanSubSurface                 = BoxBiomass_OceanSubSurface;       % (mmole N/m3); (2D matrix: num_E2Egroups X num_t)
    ODEinput.BoxBiomass_River                           = BoxBiomass_River;                 % (mmole N/m3); (2D matrix: num_E2Egroups X num_t)
    
    
    % step 11k: solve the dynamic model -----------------------------------
    %           NOTE: calculation uses ode23t (trial-and-error suggests a bit better performance than ODE45)
    %           NOTE: size of ProductionRates is 2D matrix: time X (num_E2Egroups*num_boxes)

% % %     % for use with defined ocean boundary biomass conditions (step 11i - OPTION 1 & OPTION 2)
% % %     [T, ProductionRates] = ode23t(@(t, ProductionRates_t) f_ECOTRANode_DefinedBoundary_basin_08032017(t, ProductionRates_t, ODEinput), t_grid, Production_initial(:)); % use this for getting soln at each time-point; for defined boundary conditions

    % for use with reflective boundary conditions (step 11i - OPTION 3)
    [T, ProductionRates] = ode23t(@(t, ProductionRates_t) f_ECOTRANode_ReflectiveBoundary_basin_05242017(t, ProductionRates_t, ODEinput), t_grid, Production_initial(:)); % use this for getting soln at each time-point; for reflective boundary conditions

    store_T(:, 1)                                         = T;
    store_ProductionRates(:, 1:(num_E2Egroups*num_boxes)) = ProductionRates; % (mmole N/m3/d)

    
    % step 11L: unstack result (store_ProductionRates) to retrieve spatial boxes ------------
    re_Y    = reshape(store_ProductionRates, [num_t, num_E2Egroups, num_boxes]); % (mmole N/m3/d); (3D matrix: time X groups X num_boxes)
    
    
    
    
    
    % *************************************************************************
    % STEP 12: save run results------------------------------------------------
    save(saveFile, 're_Y', 'store_T', 'PHYSICSinput', 'ECOTRANphysics', 'ODEinput'); % save model run


end % (MonteCarlo_loop)


% end m-file***************************************************************